@@ -1,6 +1,7 @@
 # deb-format -- lintian check script -*- perl -*-
 
-# Copyright (C) 2009 Russ Allbery
+# Copyright © 2009 Russ Allbery
+# Copyright © 2018 Chris Lamb <lamby@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the Free
@@ -22,13 +23,12 @@ use warnings;
 use utf8;
 use autodie;
 
-use IO::Async::Loop;
-use IO::Async::Process;
+use IPC::Run3;
 use List::MoreUtils qw(first_index none);
 use Path::Tiny;
 
 use Lintian::Data;
-use Lintian::Util qw(safe_qx);
+use Lintian::IPC::Run3 qw(safe_qx);
 
 use constant EMPTY => q{};
 use constant NEWLINE => qq{\n};
@@ -38,64 +38,32 @@ use namespace::clean;
 
 with 'Lintian::Check';
 
-# The files that contain error messages from tar, which we'll check and issue
-# tags for if they contain something unexpected, and their corresponding tags.
-# - These files are created by bin-pkg-control, index and unpacked respectively
-our %ERRORS = (
-    'control-errors'       => 'tar-errors-from-control',
-    'control-index-errors' => 'tar-errors-from-control',
-    'index-errors'         => 'tar-errors-from-data',
-    'unpacked-errors'      => 'tar-errors-from-data'
-);
-
 my $EXTRA_MEMBERS = Lintian::Data->new('deb-format/extra-members');
 
 sub installable {
     my ($self) = @_;
 
-    my $type = $self->type;
-    my $processable = $self->processable;
+    my $deb_path = $self->processable->path;
 
-    my $deb = path($processable->groupdir)->child('deb')->stringify;
+    # set to one when something is so bad that we can't continue
+    my $failed;
 
-    # Run ar t on the *.deb file.  deb will be a symlink to it.
-    my $failed; # set to one when something is so bad that we can't continue
+    my @command = ('ar', 't', $deb_path);
 
-    my $loop = IO::Async::Loop->new;
-    my $future = $loop->new_future;
+    my $stdout;
+    my $stderr;
 
-    my @command = ('ar', 't', $deb);
-    my $stdout = EMPTY;
-    my $stderr = EMPTY;
-    my $process = IO::Async::Process->new(
-        command => [@command],
-        stdout => { into => \$stdout },
-        stderr => { into => \$stderr },
-        on_finish => sub {
-            my ($self, $exitcode) = @_;
-            my $status = ($exitcode >> 8);
+    run3(\@command, \undef, \$stdout, \$stderr);
 
-            if ($status) {
-                $future->fail("Non-zero status $status from @command");
-                return;
-            }
-
-            $future->done("Done with @command");
-            return;
-        });
-
-    $loop->add($process);
-    $loop->await($future);
-
-    if ($future->is_done) {
+    unless ($?) {
         my @members = split(/\n/, $stdout);
         my $count = scalar(@members);
         my ($ctrl_member, $data_member);
         if ($count < 3) {
-            $self->tag('malformed-deb-archive',
+            $self->hint('malformed-deb-archive',
                 "found only $count members instead of 3");
         } elsif ($members[0] ne 'debian-binary') {
-            $self->tag('malformed-deb-archive',
+            $self->hint('malformed-deb-archive',
                 "first member $members[0] not debian-binary");
         } elsif (
             $count == 3 and none {
@@ -149,7 +117,7 @@ sub installable {
                 } else {
                     $text = 'unexpected member';
                 }
-                $self->tag('misplaced-extra-member-in-deb',
+                $self->hint('misplaced-extra-member-in-deb',
                     "$member ($text at position $actual_index)");
             }
         }
@@ -157,23 +125,23 @@ sub installable {
         if (not defined($ctrl_member)) {
             # Somehow I doubt we will ever get this far without a control
             # file... :)
-            $self->tag('malformed-deb-archive', 'Missing control.tar member');
+            $self->hint('malformed-deb-archive', 'Missing control.tar member');
             $failed = 1;
         } else {
             if (
                 $ctrl_member !~ m/\A
                      control\.tar(?:\.(?:gz|xz))?  \Z/xsm
             ) {
-                $self->tag(
+                $self->hint(
                     'malformed-deb-archive',
                     join(' ',
                         "second (official) member $ctrl_member",
                         'not control.tar.(gz|xz)'));
                 $failed = 1;
             } elsif ($ctrl_member eq 'control.tar') {
-                $self->tag('uses-no-compression-for-control-tarball');
+                $self->hint('uses-no-compression-for-control-tarball');
             }
-            $self->tag('control-tarball-compression-format',
+            $self->hint('control-tarball-compression-format',
                 $ctrl_member =~ s/^control\.tar\.?//r || '(none)');
         }
 
@@ -181,7 +149,7 @@ sub installable {
             # Somehow I doubt we will ever get this far without a data
             # member (i.e. I suspect unpacked and index will fail), but
             # mah
-            $self->tag('malformed-deb-archive', 'Missing data.tar member');
+            $self->hint('malformed-deb-archive', 'Missing data.tar member');
             $failed = 1;
         } else {
             if (
@@ -189,28 +157,28 @@ sub installable {
                      data\.tar(?:\.(?:gz|bz2|xz|lzma))?  \Z/xsm
             ) {
                 # wasn't okay after all
-                $self->tag(
+                $self->hint(
                     'malformed-deb-archive',
                     join(' ',
                         "third (official) member $data_member",
                         'not data.tar.(gz|xz|bz2|lzma)'));
                 $failed = 1;
-            } elsif ($type eq 'udeb'
+            } elsif ($self->processable->type eq 'udeb'
                 && $data_member !~ m/^data\.tar\.[gx]z$/) {
-                $self->tag(
+                $self->hint(
                     'udeb-uses-unsupported-compression-for-data-tarball');
             } elsif ($data_member eq 'data.tar.lzma') {
-                $self->tag('uses-deprecated-compression-for-data-tarball',
+                $self->hint('uses-deprecated-compression-for-data-tarball',
                     'lzma');
                 # Ubuntu's archive allows lzma packages.
-                $self->tag('lzma-deb-archive');
+                $self->hint('lzma-deb-archive');
             } elsif ($data_member eq 'data.tar.bz2') {
-                $self->tag('uses-deprecated-compression-for-data-tarball',
+                $self->hint('uses-deprecated-compression-for-data-tarball',
                     'bzip2');
             } elsif ($data_member eq 'data.tar') {
-                $self->tag('uses-no-compression-for-data-tarball');
+                $self->hint('uses-no-compression-for-data-tarball');
             }
-            $self->tag('data-tarball-compression-format',
+            $self->hint('data-tarball-compression-format',
                 $data_member =~ s/^data\.tar\.?//r || '(none)');
         }
     } else {
@@ -219,7 +187,7 @@ sub installable {
         $stderr =~ s/\n.*//s;
         $stderr =~ s/^ar:\s*//;
         $stderr =~ s/^deb:\s*//;
-        $self->tag('malformed-deb-archive', "ar error: $stderr");
+        $self->hint('malformed-deb-archive', "ar error: $stderr");
     }
 
     # Check the debian-binary version number.  We probably won't get
@@ -228,40 +196,13 @@ sub installable {
     # supports a newer format but it's not permitted in the archive
     # yet.
     if (not defined($failed)) {
-        my $output = safe_qx('ar', 'p', $deb, 'debian-binary');
+        my $output = safe_qx('ar', 'p', $deb_path, 'debian-binary');
         if ($? != 0) {
-            $self->tag('malformed-deb-archive',
+            $self->hint('malformed-deb-archive',
                 'cannot read debian-binary member');
         } elsif ($output !~ /^2\.\d+\n/) {
             my ($version) = split(m/\n/, $output);
-            $self->tag('malformed-deb-archive', "version $version not 2.0");
-        }
-    }
-
-    # If either control-errors or index-errors exist, tar produced
-    # error output when processing the package.  We want to report
-    # those as tags unless they're just tar noise that doesn't
-    # represent an actual problem.
-    for my $file (keys %ERRORS) {
-        my $tag = $ERRORS{$file};
-        my $path = path($processable->groupdir)->child($file)->stringify;
-        if (-s $path) {
-            open(my $fd, '<', $path);
-            while (my $line = <$fd>) {
-                chomp($line);
-                $line =~ s,^(?:[/\w]+/)?tar: ,,;
-
-                # Record size errors are harmless.  Ignore implausibly
-                # old timestamps in the data section since we already
-                # check for that elsewhere, but still warn for
-                # control.
-                next if $line =~ /^Record size =/;
-                if ($tag eq 'tar-errors-from-data') {
-                    next if $line =~ /implausibly old time stamp/;
-                }
-                $self->tag($tag, $line);
-            }
-            close($fd);
+            $self->hint('malformed-deb-archive', "version $version not 2.0");
         }
     }
 
