@@ -123,11 +123,12 @@ sub source {
               if not exists($build_systems{'dh'});
 
             if ($dhcommand eq 'dh_installmanpages') {
-                $self->tag('dh_installmanpages-is-obsolete', "line $.");
+                $self->hint('dh_installmanpages-is-obsolete', "line $.");
             }
             if (   $dhcommand eq 'dh_autotools-dev_restoreconfig'
                 or $dhcommand eq 'dh_autotools-dev_updateconfig') {
-                $self->tag('debhelper-tools-from-autotools-dev-are-deprecated',
+                $self->hint(
+                    'debhelper-tools-from-autotools-dev-are-deprecated',
                     "$dhcommand (line $.)");
                 $uses_autotools_dev_dh = 1;
             }
@@ -180,14 +181,14 @@ sub source {
                     my $depends = $dh_addons_manual->value($addon)
                       || $dh_addons->value($addon);
                     if ($addon eq 'autotools_dev') {
-                        $self->tag(
+                        $self->hint(
 'debhelper-tools-from-autotools-dev-are-deprecated',
                             "dh ... --with ${orig_addon} (line $.)"
                         );
                         $uses_autotools_dev_dh = 1;
                     }
                     $seen_dh_systemd = $. if $addon eq 'systemd';
-                    $self->tag(
+                    $self->hint(
                         'dh-quilt-addon-but-quilt-source-format',
                         "dh ... --with ${orig_addon}",
                         "(line $.)"
@@ -224,7 +225,7 @@ sub source {
             $level = $1 if ($level);
 
         } elsif (/^[^:]*(override|execute_(?:after|before))\s+(dh_[^:]*):/) {
-            $self->tag('typo-in-debhelper-override-target',
+            $self->hint('typo-in-debhelper-override-target',
                 "$1 $2", '->', "$1_$2","(line $.)");
 
         } elsif (/^([^:]*_dh_[^:]*):/) {
@@ -246,7 +247,7 @@ sub source {
                 my @near = grep { $distance{$_} < 3 } keys %distance;
                 my $nearest = min_by { $distance{$_} } @near;
 
-                $self->tag('typo-in-debhelper-override-target',
+                $self->hint('typo-in-debhelper-override-target',
                     $target, '->', $nearest, "(line $.)")
                   if length $nearest;
             }
@@ -270,7 +271,7 @@ sub source {
                 # Unknown command, so check for likely misspellings
                 my $missingauto = firstval { "dh_auto_$cmd" eq $_ }
                 $dh_commands_depends->all;
-                $self->tag('typo-in-debhelper-override-target',
+                $self->hint('typo-in-debhelper-override-target',
                     "${prefix}_$dhcommand", '->', "${prefix}_$missingauto",
                     "(line $.)")
                   if length $missingauto;
@@ -313,19 +314,19 @@ sub source {
 
     unless ($inclcdbs){
         # Okay - d/rules does not include any file in /usr/share/cdbs/
-        $self->tag('unused-build-dependency-on-cdbs')
+        $self->hint('unused-build-dependency-on-cdbs')
           if ($bdepends->implies('cdbs'));
     }
 
     if (%build_systems) {
         my @systems = sort(keys(%build_systems));
-        $self->tag('debian-build-system', join(', ', @systems));
+        $self->hint('debian-build-system', join(', ', @systems));
     } else {
-        $self->tag('debian-build-system', 'other');
+        $self->hint('debian-build-system', 'other');
     }
 
     unless ($seencommand or $inclcdbs) {
-        $self->tag('package-does-not-use-debhelper-or-cdbs');
+        $self->hint('package-does-not-use-debhelper-or-cdbs');
         return;
     }
 
@@ -343,9 +344,9 @@ sub source {
         my $all = $processable->binary_relation($binpkg, 'all');
 
         if (!$all->implies($MISC_DEPENDS)) {
-            $self->tag('debhelper-but-no-misc-depends', $binpkg);
+            $self->hint('debhelper-but-no-misc-depends', $binpkg);
         } else {
-            $self->tag('weak-dependency-on-misc-depends', $binpkg)
+            $self->hint('weak-dependency-on-misc-depends', $binpkg)
               unless $strong->implies($MISC_DEPENDS);
         }
     }
@@ -354,7 +355,7 @@ sub source {
         my $binpkg = $proc->name;
         my $breaks = $processable->binary_relation($binpkg, 'Breaks');
         my $strong = $processable->binary_relation($binpkg, 'strong');
-        $self->tag('package-uses-dh-runit-but-lacks-breaks-substvar', $binpkg)
+        $self->hint('package-uses-dh-runit-but-lacks-breaks-substvar', $binpkg)
           if $seen{'runit'}
           and $strong->implies('runit')
           and any { m,^etc/sv/, } $proc->installed->sorted_list
@@ -368,7 +369,7 @@ sub source {
         return 0 unless m,^debhelper-compat \(= (\d+)\)$,;
         $level = $1;
         $compatvirtual = $level;
-        $self->tag('debhelper-compat-virtual-relation', $compatvirtual);
+        $self->hint('debhelper-compat-virtual-relation', $compatvirtual);
         return 1;
     };
     $bdepends->visit($visit, VISIT_PRED_FULL | VISIT_STOP_FIRST_MATCH);
@@ -386,7 +387,7 @@ sub source {
                 $compat =~ s/^\s+|\s+$//g;
 
             } elsif (m/^\d/) {
-                $self->tag('debhelper-compat-file-contains-multiple-levels',
+                $self->hint('debhelper-compat-file-contains-multiple-levels',
                     "(line $.)");
             }
         }
@@ -397,56 +398,56 @@ sub source {
             # 11.1.5~alpha1) over debian/compat, except for experimental/beta
             # versions.
             if ($compat !~ m/^\d+$/) {
-                $self->tag('debhelper-compat-not-a-number', $compat);
+                $self->hint('debhelper-compat-not-a-number', $compat);
                 $compat =~ s/[^\d]//g;
                 $compat_value = $compat;
                 $compatnan = 1;
             }
             if ($level) {
                 my $c = $compat;
-                $self->tag(
+                $self->hint(
                     'declares-possibly-conflicting-debhelper-compat-versions',
-                    "rules=$level compat=${c}"
+                    "compat=${c} other=${level}"
                 );
             } else {
                 # this is not just to fill in the gap, but because debhelper
                 # prefers DH_COMPAT over debian/compat
                 $level = $compat_value;
             }
-            $self->tag('uses-debhelper-compat-file')
+            $self->hint('uses-debhelper-compat-file')
               if $compat_value >= 11
               and $compat_value < $compat_level->value('experimental');
         } else {
-            $self->tag('debhelper-compat-file-is-empty');
+            $self->hint('debhelper-compat-file-is-empty');
         }
     } else {
-        $self->tag('debhelper-compat-file-is-missing') unless $compatvirtual;
+        $self->hint('debhelper-compat-file-is-missing') unless $compatvirtual;
     }
 
     if (defined($level) and $level !~ m/^\d+$/ and not $compatnan) {
-        $self->tag('debhelper-compatibility-level-not-a-number', $level);
+        $self->hint('debhelper-compatibility-level-not-a-number', $level);
         $level =~ s/[^\d]//g;
         $compatnan = 1;
     }
 
-    $self->tag('debhelper-compat-level', $level) if defined($level);
+    $self->hint('debhelper-compat-level', $level) if defined($level);
     $level ||= 1;
     if ($level < $compat_level->value('deprecated')) {
-        $self->tag('package-uses-deprecated-debhelper-compat-version', $level);
+        $self->hint('package-uses-deprecated-debhelper-compat-version',$level);
     } elsif ($level < $compat_level->value('recommended')) {
-        $self->tag('package-uses-old-debhelper-compat-version', $level);
+        $self->hint('package-uses-old-debhelper-compat-version', $level);
     } elsif ($level >= $compat_level->value('experimental')) {
-        $self->tag('package-uses-experimental-debhelper-compat-version',
+        $self->hint('package-uses-experimental-debhelper-compat-version',
             $level);
     }
 
     if ($seendhcleank) {
-        $self->tag('dh-clean-k-is-deprecated');
+        $self->hint('dh-clean-k-is-deprecated');
     }
 
     for my $suffix (qw(enable start)) {
         my ($line, $arch) = @{$overrides{"dh_systemd_$suffix"} // []};
-        $self->tag(
+        $self->hint(
             'debian-rules-uses-deprecated-systemd-override',
             "override_dh_systemd_$suffix$arch",
             "(line $line)"
@@ -454,16 +455,16 @@ sub source {
     }
 
     my $num_overrides = scalar(keys %overrides);
-    $self->tag('excessive-debhelper-overrides', $num_overrides)
+    $self->hint('excessive-debhelper-overrides', $num_overrides)
       if $num_overrides >= 20;
 
-    $self->tag(
+    $self->hint(
         'debian-rules-uses-unnecessary-dh-argument',
         'dh ... --parallel',
         "(line $seen_dh_parallel)"
     ) if $seen_dh_parallel and $level >= 10;
 
-    $self->tag(
+    $self->hint(
         'debian-rules-uses-unnecessary-dh-argument',
         "dh ... --with=systemd (line $seen_dh_systemd)"
     ) if $seen_dh_systemd and $level >= 10;
@@ -499,7 +500,7 @@ sub source {
                 $is_udeb = 1 if $binpkg and $binpkg_type eq 'udeb';
                 $is_udeb = 1 if not $binpkg and $single_pkg eq 'udeb';
                 if (not $is_udeb) {
-                    $self->tag('maintainer-script-lacks-debhelper-token',
+                    $self->hint('maintainer-script-lacks-debhelper-token',
                         $file);
                 }
             }
@@ -509,13 +510,13 @@ sub source {
             # and [<pkg>.]NEWS
             $self->tag_if_executable($file);
         } elsif ($basename =~ m/^ex\.|\.ex$/i) {
-            $self->tag('dh-make-template-in-source', $file);
+            $self->hint('dh-make-template-in-source', $file);
         } elsif ($basename =~ m/^(?:(.*)\.)?maintscript$/) {
             next unless $file->is_open_ok;
             open(my $fd, '<', $file->unpacked_path);
             while (<$fd>) {
                 if (m/--\s+"\$(?:@|{@})"\s*$/) {
-                    $self->tag('maintscript-includes-maint-script-parameters',
+                    $self->hint('maintscript-includes-maint-script-parameters',
                         $basename, "(line $.)");
                 }
             }
@@ -524,7 +525,7 @@ sub source {
             # The regex matches "debhelper", but debhelper/Dh_Lib does not
             # make those, so skip it.
             if ($basename ne 'debhelper') {
-                $self->tag('temporary-debhelper-file', $basename);
+                $self->hint('temporary-debhelper-file', $basename);
             }
         } else {
             my $base = $basename;
@@ -545,7 +546,7 @@ sub source {
                     if ($actual and $actual->is_executable) {
                         my $cmd = _shebang_cmd($file);
                         unless ($cmd) {
-                            $self->tag(
+                            $self->hint(
 'executable-debhelper-file-without-being-executable',
                                 $file
                             );
@@ -568,7 +569,7 @@ sub source {
                     next if /^\s*$/;
                     next if (/^\#/ and $level >= 5);
                     if (m/((?<!\\)\{(?:[^\s\\\}]*?,)+[^\\\}\s,]*,*\})/) {
-                        $self->tag('brace-expansion-in-debhelper-config-file',
+                        $self->hint('brace-expansion-in-debhelper-config-file',
                             $file,$1,"(line $.)");
                         last;
                     }
@@ -581,12 +582,12 @@ sub source {
     $bdepends_noarch = $processable->relation_noarch('Build-Depends-All');
     $bdepends = $processable->relation('Build-Depends-All');
     if ($needbuilddepends) {
-        $self->tag('package-uses-debhelper-but-lacks-build-depends')
+        $self->hint('package-uses-debhelper-but-lacks-build-depends')
           unless $bdepends->implies('debhelper')
           or $bdepends->implies('debhelper-compat');
     }
     if ($needdhexecbuilddepends && !$bdepends->implies('dh-exec')) {
-        $self->tag('package-uses-dh-exec-but-lacks-build-depends');
+        $self->hint('package-uses-dh-exec-but-lacks-build-depends');
     }
 
     while (my ($dep, $command) = each %missingbdeps) {
@@ -594,18 +595,18 @@ sub source {
         next
           if $level >= 10
           and any { $_ eq $dep } qw(autotools-dev dh-strip-nondeterminism);
-        $self->tag('missing-build-dependency-for-dh_-command',
+        $self->hint('missing-build-dependency-for-dh_-command',
             "$command => $dep")
           unless ($bdepends_noarch->implies($dep));
     }
     while (my ($dep, $addon) = each %missingbdeps_addons) {
-        $self->tag('missing-build-dependency-for-dh-addon', "$addon => $dep")
+        $self->hint('missing-build-dependency-for-dh-addon', "$addon => $dep")
           unless ($bdepends_noarch->implies($dep));
 
         # As a special case, the python3 addon needs a dependency on
         # dh-python unless the -dev packages are used.
         my $pkg = 'dh-python';
-        $self->tag('missing-build-dependency-for-dh-addon',"$addon => $pkg")
+        $self->hint('missing-build-dependency-for-dh-addon',"$addon => $pkg")
           if $addon eq 'python3'
           && $bdepends_noarch->implies($dep)
           && !$bdepends_noarch->implies(
@@ -620,13 +621,13 @@ sub source {
         my @extra = ($level);
         $tagname = 'package-lacks-versioned-build-depends-on-debhelper'
           if ($dh_bd_version <= $compat_level->value('pedantic'));
-        $self->tag($tagname, @extra);
+        $self->hint($tagname, @extra);
     }
 
     if ($level >= 10) {
         for my $pkg (qw(dh-autoreconf autotools-dev)) {
             next if $pkg eq 'autotools-dev' and $uses_autotools_dev_dh;
-            $self->tag('useless-autoreconf-build-depends', $pkg)
+            $self->hint('useless-autoreconf-build-depends', $pkg)
               if $bdepends->implies($pkg);
         }
     }
@@ -640,7 +641,7 @@ sub source {
             }
         }
         if (%python_depends) {
-            $self->tag('python-depends-but-no-python-helper',
+            $self->hint('python-depends-but-no-python-helper',
                 sort(keys %python_depends));
         }
     }
@@ -653,7 +654,7 @@ sub source {
             }
         }
         if (%python3_depends) {
-            $self->tag('python3-depends-but-no-python3-helper',
+            $self->hint('python3-depends-but-no-python3-helper',
                 sort(keys %python3_depends));
         }
     }
@@ -665,7 +666,7 @@ sub source {
               if $processable->binary_relation($binpkg, 'all')
               ->implies('${sphinxdoc:Depends}');
         }
-        $self->tag('sphinxdoc-but-no-sphinxdoc-depends')
+        $self->hint('sphinxdoc-but-no-sphinxdoc-depends')
           unless $seen_sphinxdoc;
     }
 
@@ -677,7 +678,7 @@ sub tag_if_executable {
     # The permissions of symlinks are not really defined, so resolve
     # $path to ensure we are not dealing with a symlink.
     my $actual = $path->resolve_path;
-    $self->tag('package-file-is-executable', $path)
+    $self->hint('package-file-is-executable', $path)
       if $actual and $actual->is_executable;
     return;
 }
@@ -689,7 +690,7 @@ sub check_dh_exec {
     # Only /usr/bin/dh-exec is allowed, even if
     # /usr/lib/dh-exec/dh-exec-subst works too.
     if ($cmd =~ m,/usr/lib/dh-exec/,) {
-        $self->tag('dh-exec-private-helper', $path);
+        $self->hint('dh-exec-private-helper', $path);
     }
 
     my ($dhe_subst, $dhe_install, $dhe_filter) = (0, 0, 0);
@@ -706,7 +707,7 @@ sub check_dh_exec {
                       |GNU_ (?:CPU|SYSTEM|TYPE)|MULTIARCH
              ) \Z}xsm
             ) {
-                $self->tag('dh-exec-subst-unknown-variable', $path, $sv);
+                $self->hint('dh-exec-subst-unknown-variable', $path, $sv);
             }
         }
         $dhe_install = 1 if /[ \t]=>[ \t]/;
@@ -737,18 +738,18 @@ sub check_dh_exec {
                 my $form = $_;
                 chomp($form);
                 $form = "\"$form\"";
-                $self->tag('dh-exec-useless-usage', $path, $form);
+                $self->hint('dh-exec-useless-usage', $path, $form);
             }
         }
     }
     close($fd);
 
     if (!($dhe_subst || $dhe_install || $dhe_filter)) {
-        $self->tag('dh-exec-script-without-dh-exec-features', $path);
+        $self->hint('dh-exec-script-without-dh-exec-features', $path);
     }
 
     if ($dhe_install && ($base ne 'install' && $base ne 'manpages')) {
-        $self->tag('dh-exec-install-not-allowed-here', $path);
+        $self->hint('dh-exec-install-not-allowed-here', $path);
     }
 
     return;
