@@ -1,6 +1,7 @@
 # debian/debconf -- lintian check script -*- perl -*-
 
-# Copyright (C) 2001 Colin Watson
+# Copyright © 2001 Colin Watson
+# Copyright © 2020 Felix Lechner
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,22 +21,34 @@
 
 package Lintian::debian::debconf;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
-use Lintian::Deb822Parser qw(read_dpkg_control :constants);
+use List::MoreUtils qw(none);
+use Path::Tiny;
+
+use Lintian::Deb822::File;
+use Lintian::Deb822::Parser qw(:constants);
 use Lintian::Relation;
-use Lintian::Tags qw(tag);
 use Lintian::Util qw($PKGNAME_REGEX);
 
+use constant EMPTY => q{};
+use constant SPACE => q{ };
+
+use Moo;
+use namespace::clean;
+
+with 'Lintian::Check';
+
 # From debconf-devel(7), section 'THE TEMPLATES FILE', up to date with debconf
 # version 1.5.24.  Added indices for cdebconf (indicates sort order for
 # choices); debconf doesn't support it, but it ignores it, which is safe
 # behavior. Likewise, help is supported as of cdebconf 0.143 but is not yet
 # supported by debconf.
 my %template_fields
-  = map { $_ => 1 } qw(template type choices indices default description help);
+  = map { $_ => 1 } qw(Template Type Choices Indices Default Description Help);
 
 # From debconf-devel(7), section 'THE TEMPLATES FILE', up to date with debconf
 # version 1.5.24.
@@ -62,61 +75,55 @@ my $ANY_DEBCONF = Lintian::Relation->new(
           cdebconf-udeb libdebconfclient0 libdebconfclient0-udeb)
     ));
 
-sub always {
-    my ($pkg, $type, $info) = @_;
-    my ($seenconfig, $seentemplates, $usespreinst);
+sub source {
+    my ($self) = @_;
 
-    if ($type eq 'source') {
-        my @binaries = $info->binaries;
-        my @files = map { "$_.templates" } @binaries;
-        push @files, 'templates';
+    my @catalogs= (
+        'templates',
+        map { "$_.templates" }$self->processable->debian_control->installables
+    );
+    my @files = grep { defined }
+      map { $self->processable->patched->resolve_path("debian/$_") } @catalogs;
 
-        foreach my $file (@files) {
-            my $dfile = "debian/$file";
-            my $templates_file = $info->index_resolved_path($dfile);
-            my $binary = $file;
-            $binary =~ s/\.?templates$//;
-            # Single binary package (so @files contains "templates" and
-            # "binary.templates")?
-            if (!$binary && @files == 2) {
-                $binary = $binaries[0];
-            }
+    my @utf8 = grep { $_->is_valid_utf8 } @files;
+    for my $file (@utf8) {
 
-            if ($templates_file and $templates_file->is_open_ok) {
-                my @templates;
-                eval {
-                    @templates
-                      = read_dpkg_control($templates_file->fs_path,
-                        DCTRL_DEBCONF_TEMPLATE);
-                };
-                if ($@) {
-                    chomp $@;
-                    $@ =~ s/^internal error: //;
-                    $@ =~ s/^syntax error in //;
-                    tag 'syntax-error-in-debconf-template', "$file: $@";
-                    next;
-                }
+        my $contents = $file->decoded_utf8;
+        my $deb822 = Lintian::Deb822::File->new;
 
-                foreach my $template (@templates) {
-                    if (    exists $template->{template}
-                        and exists $template->{_choices}) {
-                        tag 'template-uses-unsplit-choices',
-                          "$binary - $template->{template}";
-                    }
-                }
-            }
+        my @templates;
+        eval {
+            @templates
+              = $deb822->parse_string($contents, DCTRL_DEBCONF_TEMPLATE);
+        };
+
+        if (length $@) {
+            chomp $@;
+
+            $@ =~ s/^syntax error in //;
+            $self->hint('syntax-error-in-debconf-template',"$file: $@");
+
+            next;
         }
 
-        # The remainder of the checks are for binary packages, so we exit now
-        return;
+        my @unsplit_choices
+          = grep {$_->exists('Template') && $_->exists('_Choices')}@templates;
+
+        $self->hint('template-uses-unsplit-choices',
+            $file->name, $_->value('Template'))
+          for @unsplit_choices;
     }
 
-    my $preinst = $info->control_index('preinst');
-    my $ctrl_config = $info->control_index('config');
-    my $ctrl_templates = $info->control_index('templates');
+    return;
+}
 
+sub installable {
+    my ($self) = @_;
+
+    my $usespreinst;
+    my $preinst = $self->processable->control->lookup('preinst');
     if ($preinst and $preinst->is_file and $preinst->is_open_ok) {
-        my $fd = $preinst->open;
+        open(my $fd, '<', $preinst->unpacked_path);
         while (<$fd>) {
             s/\#.*//;    # Not perfect for Perl, but should be OK
             if (   m,/usr/share/debconf/confmodule,
@@ -128,32 +135,48 @@ sub always {
         close($fd);
     }
 
-    $seenconfig = 1 if $ctrl_config and $ctrl_config->is_file;
+    my $seenconfig;
+    my $ctrl_config = $self->processable->control->lookup('config');
+    if (defined $ctrl_config && $ctrl_config->is_file) {
+
+        $self->hint('debconf-config-not-executable')
+          unless $ctrl_config->is_executable;
+
+        $seenconfig = 1;
+    }
+
+    my $seentemplates;
+    my $ctrl_templates = $self->processable->control->lookup('templates');
     $seentemplates = 1 if $ctrl_templates and $ctrl_templates->is_file;
 
     # This still misses packages that use debconf only in the postrm.
     # Packages that ask debconf questions in the postrm should load
     # the confmodule in the postinst so that debconf can register
     # their templates.
-    return unless $seenconfig or $seentemplates or $usespreinst;
+    return
+         unless $seenconfig
+      or $seentemplates
+      or $usespreinst;
 
     # parse depends info for later checks
 
     # Consider every package to depend on itself.
     my $selfrel;
-    if (defined $info->field('version')) {
-        $_ = $info->field('version');
-        $selfrel = "$pkg (= $_)";
+    if ($self->processable->fields->exists('Version')) {
+        $_ = $self->processable->fields->value('Version');
+        $selfrel = $self->processable->name . " (= $_)";
     } else {
-        $selfrel = "$pkg";
+        $selfrel = $self->processable->name;
     }
 
     # Include self and provides as a package providing debconf presumably
     # satisfies its own use of debconf (if any).
     my $selfrelation
-      = Lintian::Relation->and($info->relation('provides'), $selfrel);
+      = Lintian::Relation->and($self->processable->relation('Provides'),
+        $selfrel);
     my $alldependencies
-      = Lintian::Relation->and($info->relation('strong'), $selfrelation);
+      = Lintian::Relation->and($self->processable->relation('strong'),
+        $selfrelation);
 
     # See if the package depends on dbconfig-common.  Packages that do
     # are allowed to have a config file with no templates, since they
@@ -162,138 +185,153 @@ sub always {
 
     # Check that both debconf control area files are present.
     if ($seenconfig and not $seentemplates and not $usesdbconfig) {
-        tag 'no-debconf-templates';
+        $self->hint('no-debconf-templates');
     } elsif ($seentemplates
         and not $seenconfig
         and not $usespreinst
-        and $type ne 'udeb') {
-        tag 'no-debconf-config';
-    }
-
-    if ($seenconfig and not $ctrl_config->is_executable) {
-        tag 'debconf-config-not-executable';
+        and $self->processable->type ne 'udeb') {
+        $self->hint('no-debconf-config');
     }
 
     # Lots of template checks.
 
-    my (@templates, %potential_db_abuse, @templates_seen);
-
+    my @templates;
     if ($seentemplates) {
-        eval {
-            # $seentemplates (above) will be false if $ctrl_templates is a
-            # symlink or not a file, so this should be safe without
-            # (re-checking) with -f/-l.
-            @templates
-              = read_dpkg_control($ctrl_templates->fs_path,
-                DCTRL_DEBCONF_TEMPLATE);
-        };
-        if ($@) {
-            chomp $@;
-            $@ =~ s/^internal error: //;
-            $@ =~ s/^syntax error in //;
-            tag 'syntax-error-in-debconf-template', "templates: $@";
-            @templates = ();
+
+        if ($ctrl_templates->is_valid_utf8) {
+            my $contents = $ctrl_templates->decoded_utf8;
+            my $deb822 = Lintian::Deb822::File->new;
+
+            eval {
+                # $seentemplates (above) will be false if $ctrl_templates is a
+                # symlink or not a file, so this should be safe without
+                # (re-checking) with -f/-l.
+                @templates
+                  = $deb822->parse_string($contents,DCTRL_DEBCONF_TEMPLATE);
+            };
+
+            if (length $@) {
+                chomp $@;
+
+                $@ =~ s/^syntax error in //;
+                $self->hint(
+                    'syntax-error-in-debconf-template',
+                    "DEBIAN/$ctrl_templates: $@"
+                );
+
+                @templates = ();
+            }
         }
     }
 
-    foreach my $template (@templates) {
-        my $isselect = '';
+    my @templates_seen;
+    my %potential_db_abuse;
+    for my $template (@templates) {
+        my $isselect = EMPTY;
+
+        my $name = $template->value('Template');
+        if (!$template->exists('Template')) {
+            $self->hint('no-template-name');
+            $name = 'no-template-name';
 
-        if (not exists $template->{template}) {
-            tag 'no-template-name';
-            $template->{template} = 'no-template-name';
         } else {
-            push @templates_seen, $template->{template};
-            if ($template->{template}!~m|[A-Za-z0-9.+-](?:/[A-Za-z0-9.+-])|) {
-                tag 'malformed-template-name', "$template->{template}";
-            }
+            push @templates_seen, $name;
+            $self->hint('malformed-template-name', $name)
+              unless $name =~ m{[A-Za-z0-9.+-](?:/[A-Za-z0-9.+-])};
         }
 
-        if (not exists $template->{type}) {
-            tag 'no-template-type', "$template->{template}";
-        } elsif (not $valid_types{$template->{type}}) {
+        my $type = $template->value('Type');
+        if (!$template->exists('Type')) {
+            $self->hint('no-template-type', $name);
+
+        } elsif (!$valid_types{$type}) {
             # cdebconf has a special "entropy" type
-            tag 'unknown-template-type', "$template->{type}"
-              unless ($template->{type} eq 'entropy'
-                and $alldependencies->implies('cdebconf'));
-        } elsif ($template->{type} eq 'select') {
+            $self->hint('unknown-template-type', $type)
+              unless $type eq 'entropy'
+              && $alldependencies->implies('cdebconf');
+
+        } elsif ($type eq 'select' || $type eq 'multiselect') {
             $isselect = 1;
-        } elsif ($template->{type} eq 'multiselect') {
-            $isselect = 1;
-        } elsif ($template->{type} eq 'boolean') {
-            tag 'boolean-template-has-bogus-default',
-              "$template->{template} $template->{default}"
-              if defined $template->{default}
-              and $template->{default} ne 'true'
-              and $template->{default} ne 'false';
+
+        } elsif ($type eq 'boolean') {
+            my $default = $template->value('Default');
+            $self->hint('boolean-template-has-bogus-default', $name, $default)
+              if $template->exists('Default')
+              && (none { $default eq $_ } ('true', 'false'));
         }
 
-        if ($template->{choices} && ($template->{choices} !~ /^\s*$/)) {
-            my $nrchoices = count_choices($template->{choices});
-            for my $key (keys %$template) {
-                if ($key =~ /^choices-/) {
-                    if (!$template->{$key} || ($template->{$key} =~ /^\s*$/o)){
-                        tag 'empty-translated-choices',
-                          "$template->{template} $key";
+        my $choices = $template->value('Choices');
+        if ($template->exists('Choices') && $choices !~ /^\s*$/) {
+
+            my $nrchoices = count_choices($choices);
+            for my $key ($template->names) {
+
+                if ($key =~ /^Choices-/) {
+                    my $translated = $template->value($key);
+                    if (!length($translated) || $translated =~ /^\s*$/){
+                        $self->hint('empty-translated-choices', $name, $key);
                     }
-                    if (count_choices($template->{$key}) != $nrchoices) {
-                        tag 'mismatch-translated-choices',
-                          "$template->{template} $key";
+
+                    if (count_choices($translated) != $nrchoices) {
+                        $self->hint('mismatch-translated-choices', $name,$key);
                     }
                 }
             }
-            if ($template->{choices} =~ /^\s*(yes\s*,\s*no|no\s*,\s*yes)\s*$/i)
-            {
-                tag 'select-with-boolean-choices', "$template->{template}";
-            }
+
+            $self->hint('select-with-boolean-choices', $name)
+              if $choices =~ /^\s*(yes\s*,\s*no|no\s*,\s*yes)\s*$/i;
         }
 
-        if ($isselect and not exists $template->{choices}) {
-            tag 'select-without-choices', "$template->{template}";
-        }
+        $self->hint('select-without-choices', $name)
+          if $isselect && !$template->exists('Choices');
 
-        if (not exists $template->{description}) {
-            tag 'no-template-description', "$template->{template}";
-        } elsif ($template->{description}=~m/^\s*(.*?)\s*?\n\s*\1\s*$/) {
+        my $description = $template->value('Description');
+        $self->hint('no-template-description', $name)
+          unless length $description
+          || length $template->value('_Description');
+
+        if ($description =~ /^\s*(.*?)\s*?\n\s*\1\s*$/){
             # Check for duplication. Should all this be folded into the
             # description checks?
-            tag 'duplicate-long-description-in-template',
-              "$template->{template}";
+            $self->hint('duplicate-long-description-in-template',$name);
         }
 
         my %languages;
-        foreach my $field (sort keys %$template) {
+        for my $field ($template->names) {
             # Tests on translations
             my ($mainfield, $lang) = split m/-/, $field, 2;
             if (defined $lang) {
                 $languages{$lang}{$mainfield}=1;
             }
-            unless ($template_fields{$mainfield}){ # Ignore language codes here
-                tag 'unknown-field-in-templates',
-                  "$template->{template} $field";
+            my $stripped = $mainfield;
+            $stripped =~ s/^_//;
+            unless ($template_fields{$stripped}) {
+                # Ignore language codes here
+                $self->hint('unknown-field-in-templates',$name, $field);
             }
         }
 
-        if ($template->{template} && $template->{type}) {
-            $potential_db_abuse{$template->{template}} = 1
-              if ( ($template->{type} eq 'note')
-                or ($template->{type} eq 'text'));
+        if (length $name && length $type) {
+            $potential_db_abuse{$name} = 1
+              if $type eq 'note' || $type eq 'text';
         }
 
         # Check the description against the best practices in the
         # Developer's Reference, but skip all templates where the
         # short description contains the string "for internal use".
         my ($short, $extended);
-        if (defined $template->{description}) {
-            ($short, $extended) = split(/\n/, $template->{description}, 2);
+        if (length $description) {
+            ($short, $extended) = split(/\n/, $description, 2);
             unless (defined $short) {
-                $short = $template->{description};
-                $extended = '';
+                $short = $description;
+                $extended = EMPTY;
             }
         } else {
-            ($short, $extended) = ('', '');
+            $short = EMPTY;
+            $extended = EMPTY;
         }
-        my $ttype = $template->{type} || '';
+
+        my $ttype = $type;
         unless ($short =~ /for internal use/i) {
             my $isprompt = grep { $_ eq $ttype } qw(string password);
             if ($isprompt) {
@@ -302,60 +340,59 @@ sub always {
                     && (   $short !~ m/:$/
                         || $short =~ m/^(what|who|when|where|which|how)/i)
                 ) {
-                    tag 'malformed-prompt-in-templates', $template->{template};
+                    $self->hint('malformed-prompt-in-templates',$name);
                 }
             }
             if ($isselect) {
                 if ($short =~ /^(Please|Cho+se|Enter|Select|Specify|Give)/) {
-                    tag 'using-imperative-form-in-templates',
-                      $template->{template};
+                    $self->hint('using-imperative-form-in-templates',$name);
                 }
             }
             if ($ttype eq 'boolean') {
                 if ($short !~ /\?/) {
-                    tag 'malformed-question-in-templates',
-                      $template->{template};
+                    $self->hint('malformed-question-in-templates',$name);
                 }
             }
-            if (defined($extended) && $extended =~ /[^\?]\?(\s+|$)/) {
-                tag 'using-question-in-extended-description-in-templates',
-                  $template->{template};
+            if (defined $extended && $extended =~ /[^\?]\?(\s+|$)/) {
+                $self->hint(
+                    'using-question-in-extended-description-in-templates',
+                    $name);
             }
             if ($ttype eq 'note') {
                 if ($short =~ /[.?;:]$/) {
-                    tag 'malformed-title-in-templates', $template->{template};
+                    $self->hint('malformed-title-in-templates',$name);
                 }
             }
             if (length($short) > 75) {
-                tag 'too-long-short-description-in-templates',
-                  $template->{template}
-                  unless $type eq 'udeb' && $ttype eq 'text';
+                $self->hint('too-long-short-description-in-templates',$name)
+                  unless $self->processable->type eq 'udeb'
+                  && $ttype eq 'text';
             }
-            if (defined $template->{description}) {
-                if ($template->{description}
+            if (defined $description) {
+                if ($description
                     =~ /(\A|\s)(I|[Mm]y|[Ww]e|[Oo]ur|[Oo]urs|mine|myself|ourself|me|us)(\Z|\s)/
                 ) {
-                    tag 'using-first-person-in-templates',
-                      $template->{template};
+                    $self->hint('using-first-person-in-templates',$name);
                 }
-                if (    $template->{description} =~ /[ \'\"]yes[ \'\",;.]/i
+                if (    $description =~ /[ \'\"]yes[ \'\",;.]/i
                     and $ttype eq 'boolean') {
-                    tag 'making-assumptions-about-interfaces-in-templates',
-                      $template->{template};
+                    $self->hint(
+                        'making-assumptions-about-interfaces-in-templates',
+                        $name);
                 }
             }
 
             # Check whether the extended description is too long.
             if ($extended) {
                 my $lines = 0;
-                for my $string (split("\n", $extended)) {
+                for my $string (split(/\n/, $extended)) {
                     while (length($string) > 80) {
-                        my $pos = rindex($string, ' ', 80);
+                        my $pos = rindex($string, SPACE, 80);
                         if ($pos == -1) {
-                            $pos = index($string, ' ');
+                            $pos = index($string, SPACE);
                         }
                         if ($pos == -1) {
-                            $string = '';
+                            $string = EMPTY;
                         } else {
                             $string = substr($string, $pos + 1);
                             $lines++;
@@ -364,8 +401,8 @@ sub always {
                     $lines++;
                 }
                 if ($lines > 20) {
-                    tag 'too-long-extended-description-in-templates',
-                      $template->{template};
+                    $self->hint('too-long-extended-description-in-templates',
+                        $name);
                 }
             }
         }
@@ -377,11 +414,11 @@ sub always {
     my (%templates_used, %template_aliases);
     for my $file (qw(config prerm postrm preinst postinst)) {
         my $potential_makedev = {};
-        my $path = $info->control_index($file);
+        my $path = $self->processable->control->lookup($file);
         if ($path and $path->is_file and $path->is_open_ok) {
             my ($usesconfmodule, $obsoleteconfmodule, $db_input, $isdefault);
 
-            my $fd = $path->open;
+            open(my $fd, '<', $path->unpacked_path);
             # Only check scripts.
             my $fl = <$fd>;
             unless ($fl && $fl =~ /^\#!/) {
@@ -407,7 +444,7 @@ sub always {
                    Debian::DebConf::Client::ConfModule),x
                 ) {
                     my $cmod = $1;
-                    tag 'loads-obsolete-confmodule', "$file:$. $cmod";
+                    $self->hint('loads-obsolete-confmodule', "$file:$. $cmod");
                     $usesconfmodule = 1;
                     $obsoleteconfmodule = 1;
                 }
@@ -419,8 +456,8 @@ sub always {
                     and m/db_input/
                     and not $config_calls_db_input) {
                     # TODO: Perl?
-                    tag 'postinst-uses-db-input'
-                      unless $type eq 'udeb';
+                    $self->hint('postinst-uses-db-input')
+                      unless $self->processable->type eq 'udeb';
                     $db_input=1;
                 }
                 if (m%/dev/%) {
@@ -431,12 +468,12 @@ sub always {
                      [\"\']? (\S+?) [\"\']? \s+ (\S+)\s/xsm
                 ) {
                     my ($priority, $template) = ($1, $2);
-                    $templates_used{get_template_name($info, $template)} = 1;
+                    $templates_used{$self->get_template_name($template)}= 1;
                     if ($priority !~ /^\$\S+$/) {
-                        tag 'unknown-debconf-priority', "$file:$. $1"
+                        $self->hint('unknown-debconf-priority', "$file:$. $1")
                           unless ($valid_priorities{$priority});
-                        tag 'possible-debconf-note-abuse',
-                          "$file:$. $template"
+                        $self->hint('possible-debconf-note-abuse',
+                            "$file:$. $template")
                           if (
                             $potential_db_abuse{$template}
                             and (
@@ -449,7 +486,7 @@ sub always {
                     m/ \A \s* (?:db_get|db_set(?:title)?) \s+ 
                        [\"\']? (\S+?) [\"\']? (?:\s|\Z)/xsm
                 ) {
-                    $templates_used{get_template_name($info, $1)} = 1;
+                    $templates_used{$self->get_template_name($1)} = 1;
                 }
                 # Try to handle Perl somewhat.
                 if (   m/^\s*(?:.*=\s*get|set)\s*\(\s*[\"\'](\S+?)[\"\']/
@@ -462,7 +499,7 @@ sub always {
                 }
                 if (not $isdefault and m/db_fset.*isdefault/) {
                     # TODO: Perl?
-                    tag 'isdefault-flag-is-deprecated', $file;
+                    $self->hint('isdefault-flag-is-deprecated', $file);
                     $isdefault = 1;
                 }
                 if (not $db_purge and m/db_purge/) {    # TODO: Perl?
@@ -472,8 +509,8 @@ sub always {
 
             if ($file eq 'postinst' or $file eq 'config') {
                 unless ($usesconfmodule) {
-                    tag "$file-does-not-load-confmodule"
-                      unless ($type eq 'udeb'
+                    $self->hint("$file-does-not-load-confmodule")
+                      unless ($self->processable->type eq 'udeb'
                         || ($file eq 'postinst' && !$seenconfig));
                 }
             }
@@ -483,20 +520,20 @@ sub always {
                 # package is a debconf provider (in which case db_purge
                 # won't be available)
                 unless ($db_purge or $selfrelation->implies($ANY_DEBCONF)) {
-                    tag 'postrm-does-not-purge-debconf';
+                    $self->hint('postrm-does-not-purge-debconf');
                 }
             }
 
             close($fd);
         } elsif ($file eq 'postinst') {
-            tag 'postinst-does-not-load-confmodule'
-              unless ($type eq 'udeb' || !$seenconfig);
+            $self->hint('postinst-does-not-load-confmodule')
+              unless ($self->processable->type eq 'udeb' || !$seenconfig);
         } elsif ($file eq 'postrm') {
             # Make an exception for debconf providing packages as some of
             # them (incl. "debconf" itself) cleans up in prerm and have no
             # postrm script at all.
-            tag 'postrm-does-not-purge-debconf'
-              unless $type eq 'udeb'
+            $self->hint('postrm-does-not-purge-debconf')
+              unless $self->processable->type eq 'udeb'
               or $selfrelation->implies($ANY_DEBCONF);
         }
     }
@@ -517,8 +554,10 @@ sub always {
             }
         }
 
-        unless ($used or $pkg eq 'debconf' or $type eq 'udeb') {
-            tag 'unused-debconf-template', $template
+        unless ($used
+            or $self->processable->name eq 'debconf'
+            or $self->processable->type eq 'udeb') {
+            $self->hint('unused-debconf-template', $template)
               unless $template =~ m,^shared/packages-(wordlist|ispell)$,
               or $template =~ m,/languages$,;
         }
@@ -528,13 +567,15 @@ sub always {
     # package that might provide debconf functionality.
 
     if ($usespreinst) {
-        unless ($info->relation('pre-depends')->implies($ANY_DEBCONF)) {
-            tag 'missing-debconf-dependency-for-preinst'
-              unless $type eq 'udeb';
+        unless (
+            $self->processable->relation('Pre-Depends')->implies($ANY_DEBCONF))
+        {
+            $self->hint('missing-debconf-dependency-for-preinst')
+              unless $self->processable->type eq 'udeb';
         }
     } else {
         unless ($alldependencies->implies($ANY_DEBCONF) or $usesdbconfig) {
-            tag 'missing-debconf-dependency';
+            $self->hint('missing-debconf-dependency');
         }
     }
 
@@ -544,17 +585,23 @@ sub always {
     # the following checks is ignored if the package being checked is debconf
     # itself.
 
-    return if ($pkg eq 'debconf') || ($type eq 'udeb');
+    return
+      if ($self->processable->name eq 'debconf')
+      || ($self->processable->type eq 'udeb');
 
-    foreach my $filename (sort keys %{$info->scripts}) {
-        my $path = $info->index_resolved_path($filename);
-        next if not $path or not $path->is_open_ok;
-        my $fd = $path->open;
+    my @scripts
+      = grep { $_->is_script } $self->processable->installed->sorted_list;
+    foreach my $file (@scripts) {
+
+        next
+          unless $file->is_open_ok;
+
+        open(my $fd, '<', $file->unpacked_path);
         while (<$fd>) {
             s/#.*//;    # Not perfect for Perl, but should be OK
             if (   m,/usr/share/debconf/confmodule,
                 or m/(?:Debconf|Debian::DebConf)::Client::ConfModule/) {
-                tag 'debconf-is-not-a-registry', $filename;
+                $self->hint('debconf-is-not-a-registry', $file->name);
                 last;
             }
         }
@@ -588,9 +635,10 @@ sub count_choices {
 
 # Manually interpolate shell variables, eg. $DPKG_MAINTSCRIPT_PACKAGE
 sub get_template_name {
-    my ($info, $name) = @_;
+    my ($self, $name) = @_;
 
-    return $name =~ s/^\$DPKG_MAINTSCRIPT_PACKAGE/$info->{name}/r;
+    my $package = $self->processable->name;
+    return $name =~ s/^\$DPKG_MAINTSCRIPT_PACKAGE/$package/r;
 }
 
 1;
