@@ -32,18 +32,10 @@ with 'Lintian::Check';
 sub always {
     my ($self) = @_;
 
-    my @all = keys %{$self->processable->field};
+    my @all = $self->processable->fields->names;
+    my @empty = grep { !length $self->processable->fields->value($_) } @all;
 
-    for my $name (@all) {
-
-        my $value = $self->processable->field($name);
-
-        # title-case the field name
-        (my $label = $name) =~ s/\b(\w)/\U$1/g;
-
-        $self->tag('empty-field', $label)
-          if $value =~ /^\s*$/;
-    }
+    $self->hint('empty-field', $_) for @empty;
 
     return;
 }
