@@ -1,6 +1,6 @@
 # files/bugs -- lintian check script -*- perl -*-
 
-# Copyright (C) 1998 Christian Schwarz and Richard Braakman
+# Copyright © 1998 Christian Schwarz and Richard Braakman
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,14 +30,14 @@ use namespace::clean;
 
 with 'Lintian::Check';
 
-sub files {
+sub visit_installed_files {
     my ($self, $file) = @_;
 
     return
       unless $file->is_dir;
 
     if ($file->name =~ m,/\.(?:be|ditrack)/?$,) {
-        $self->tag('package-contains-bts-control-dir', $file->name);
+        $self->hint('package-contains-bts-control-dir', $file->name);
     }
 
     return;
