@@ -1,6 +1,7 @@
 # group-checks -- lintian check script -*- perl -*-
 
-# Copyright (C) 2011 Niels Thykier <niels@thykier.net>
+# Copyright © 2011 Niels Thykier <niels@thykier.net>
+# Copyright © 2018 Chris Lamb <lamby@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,22 +20,29 @@
 # MA 02110-1301, USA.
 
 package Lintian::group_checks;
-use strict;
+
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use List::MoreUtils qw(any);
 
 use Lintian::Data;
 use Lintian::Relation;
-use Lintian::Tags qw(tag);
+
+use Moo;
+use namespace::clean;
+
+with 'Lintian::Check';
 
 my $KNOWN_DBG_PACKAGE = Lintian::Data->new('common/dbg-pkg',qr/\s*\~\~\s*/,
     sub { return qr/$_[0]/xms; });
 
 sub source {
+    my ($self) = @_;
 
-    my (undef, undef, undef, undef, $group) = @_;
+    my $group = $self->group;
 
     ## To find circular dependencies, we will first generate Strongly
     ## Connected Components using Tarjan's algorithm
@@ -44,20 +52,19 @@ sub source {
 
     # The packages a.k.a. nodes
     my (@nodes, %edges, $sccs);
-    my $ginfo = $group->info;
     my @procs = $group->get_processables('binary');
 
-    _check_file_overlap(@procs);
+    $self->check_file_overlap(@procs);
 
-    foreach my $proc (@procs) {
-        my $deps = $ginfo->direct_dependencies($proc);
+    foreach my $processable (@procs) {
+        my $deps = $group->direct_dependencies($processable);
         if (scalar @$deps > 0) {
             # it depends on another package - it can cause
             # a circular dependency
-            my $pname = $proc->pkg_name;
+            my $pname = $processable->name;
             push @nodes, $pname;
-            $edges{$pname} = [map { $_->pkg_name } @$deps];
-            _check_multiarch($proc, $deps);
+            $edges{$pname} = [map { $_->name } @$deps];
+            $self->check_multiarch($processable, $deps);
         }
     }
 
@@ -70,93 +77,102 @@ sub source {
     foreach my $comp (@$sccs) {
         # It takes two to tango... erh. make a circular dependency.
         next if scalar @$comp < 2;
-        tag 'intra-source-package-circular-dependency', sort @$comp;
+        $self->hint('intra-source-package-circular-dependency', sort @$comp);
     }
 
     return;
 }
 
-sub _check_file_overlap {
-    my (@procs) = @_;
+sub check_file_overlap {
+    my ($self, @procs) = @_;
     # Sort them for stable output
-    my @sorted = sort { $a->pkg_name cmp $b->pkg_name } @procs;
+    my @sorted = sort { $a->name cmp $b->name } @procs;
     for (my $i = 0 ; $i < scalar @sorted ; $i++) {
-        my $proc = $sorted[$i];
-        my $pinfo = $proc->info;
-        my @p = grep { $_ } split(m/,/o, $pinfo->field('provides', ''));
-        my $prov = Lintian::Relation->new(join(' |̈́ ', $proc->pkg_name, @p));
+        my $processable = $sorted[$i];
+
+        my @p= grep { $_ }
+          split(/,/, $processable->fields->value('Provides'));
+        my $prov
+          = Lintian::Relation->new(join(' |̈́ ', $processable->name, @p));
         for (my $j = $i ; $j < scalar @sorted ; $j++) {
             my $other = $sorted[$j];
-            my $oinfo = $other->info;
-            my @op = grep { $_ } split(m/,/o, $oinfo->field('provides', ''));
-            my $oprov
-              = Lintian::Relation->new(join(' | ', $other->pkg_name, @op));
+
+            my @op= grep { $_ }
+              split(/,/, $other->fields->value('Provides'));
+            my $oprov= Lintian::Relation->new(join(' | ', $other->name, @op));
             # poor man's "Multi-arch: same" work-around.
-            next if $proc->pkg_name eq $other->pkg_name;
+            next if $processable->name eq $other->name;
 
-            # $other conflicts/replaces with $proc
-            next if $oinfo->relation('conflicts')->implies($prov);
-            next if $oinfo->relation('replaces')->implies($proc->pkg_name);
+            # $other conflicts/replaces with $processable
+            next if $other->relation('Conflicts')->implies($prov);
+            next if $other->relation('Replaces')->implies($processable->name);
 
-            # $proc conflicts/replaces with $other
-            next if $pinfo->relation('conflicts')->implies($oprov);
-            next if $pinfo->relation('replaces')->implies($other->pkg_name);
+            # $processable conflicts/replaces with $other
+            next if $processable->relation('Conflicts')->implies($oprov);
+            next if $processable->relation('Replaces')->implies($other->name);
 
-            _overlap_check($proc, $pinfo, $other, $oinfo);
+            $self->overlap_check($processable, $processable, $other, $other);
         }
     }
     return;
 }
 
-sub _overlap_check {
-    my ($a_proc, $a_info, $b_proc, $b_info) = @_;
-    foreach my $a_file ($a_info->sorted_index) {
+sub overlap_check {
+    my ($self, $a_proc, $a_info, $b_proc, $b_info) = @_;
+    foreach my $a_file ($a_info->installed->sorted_list) {
         my $name = $a_file->name;
         my $b_file;
-        $name =~ s,/$,,o;
-        $b_file = $b_info->index($name) // $b_info->index("$name/");
+        $name =~ s,/$,,;
+        $b_file = $b_info->installed->lookup($name)
+          // $b_info->installed->lookup("$name/");
         if ($b_file) {
             next if $a_file->is_dir and $b_file->is_dir;
-            tag 'binaries-have-file-conflict', $a_proc->pkg_name,
-              $b_proc->pkg_name, $name;
+            $self->hint('binaries-have-file-conflict',
+                $a_proc->name,$b_proc->name, $name);
         }
     }
     return;
 }
 
-sub _check_multiarch {
-    my ($proc, $deps) = @_;
-    my $ma = $proc->info->field('multi-arch', 'no');
+sub check_multiarch {
+    my ($self, $processable, $deps) = @_;
+
+    my $ma = $processable->fields->value('Multi-Arch') || 'no';
     if ($ma eq 'same') {
         foreach my $dep (@$deps) {
-            my $dma = $dep->info->field('multi-arch', 'no');
+            my $dma = $dep->fields->value('Multi-Arch') || 'no';
             if ($dma eq 'same' or $dma eq 'foreign') {
                 1; # OK
             } else {
-                tag 'dependency-is-not-multi-archified',
-                  join(q{ },
-                    $proc->pkg_name, 'depends on',
-                    $dep->pkg_name, "(multi-arch: $dma)");
+                $self->hint(
+                    'dependency-is-not-multi-archified',
+                    join(q{ },
+                        $processable->name, 'depends on',
+                        $dep->name, "(multi-arch: $dma)"));
             }
         }
     } elsif ($ma ne 'same'
-        and $proc->info->field('section', 'none') =~ m,(?:^|/)debug$,o) {
+        and ($processable->fields->value('Section') || 'none')
+        =~ m,(?:^|/)debug$,) {
         # Debug package that isn't M-A: same, exploit that (non-debug)
         # dependencies is (almost certainly) a package for which the
         # debug carries debug symbols.
         foreach my $dep (@$deps) {
-            my $dma = $dep->info->field('multi-arch', 'no');
-            if (    $dma eq 'same'
-                and $dep->info->field('section', 'none') !~ m,(?:^|/)debug$,o){
+            my $dma = $dep->fields->value('Multi-Arch') || 'no';
+            if ($dma eq 'same'
+                and ($dep->fields->value('Section') || 'none')
+                !~ m,(?:^|/)debug$,){
 
                 # Debug package isn't M-A: same, but depends on a
                 # package that is from same source that isn't a debug
                 # package and that is M-A same.  Thus it is not
                 # possible to install debug symbols for all
                 # (architecture) variants of the binaries.
-                tag 'debug-package-for-multi-arch-same-pkg-not-coinstallable',
-                  $proc->pkg_name . ' => ' . $dep->pkg_name
-                  unless any { $proc->pkg_name =~ m/$_/xms }
+                $self->hint(
+                    'debug-package-for-multi-arch-same-pkg-not-coinstallable',
+                    $processable->name . ' => ' . $dep->name
+                  )
+                  unless any { $processable->name =~ m/$_/xms }
                 $KNOWN_DBG_PACKAGE->all;
             }
         }
