@@ -1,6 +1,6 @@
 # languages/python/scripts -- lintian check script -*- perl -*-
 #
-# Copyright (C) 2016 Chris Lamb
+# Copyright © 2016 Chris Lamb
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ use namespace::clean;
 
 with 'Lintian::Check';
 
-sub files {
+sub visit_installed_files {
     my ($self, $file) = @_;
 
     return
@@ -41,7 +41,7 @@ sub files {
 
     my $interpreter = $file->script->{interpreter};
 
-    $self->tag('script-uses-unversioned-python-in-shebang', $file)
+    $self->hint('script-uses-unversioned-python-in-shebang', $file)
       if $interpreter =~ m,^(/usr/bin/)?python$,;
 
     return;
