@@ -34,7 +34,7 @@ sub visit_installed_files {
     my ($self, $file) = @_;
 
     if ($file->name =~ m,^usr/share/linda/overrides/\S+,) {
-        $self->tag('package-contains-linda-override', $file->name);
+        $self->hint('package-contains-linda-override', $file->name);
     }
 
     return;
