@@ -1,6 +1,7 @@
 # systemd -- lintian check script -*- perl -*-
 #
 # Copyright © 2013 Michael Stapelberg
+# Copyright © 2016-2020 Chris Lamb <lamby@debian.org>
 #
 # based on the apache2 checks file by:
 # Copyright © 2012 Arno Töll
@@ -23,19 +24,24 @@
 
 package Lintian::systemd;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use File::Basename;
 use List::MoreUtils qw(any first_index);
 use Text::ParseWords qw(shellwords);
 
-use Lintian::Tags qw(tag);
-use Lintian::Util qw(internal_error lstrip rstrip);
-
 use Lintian::Data;
 
+use Moo;
+use namespace::clean;
+
+with 'Lintian::Check';
+
+has timers => (is => 'rwp', default => sub{ [] });
+
 # Init scripts that do not need a service file
 my $INIT_WHITELIST = Lintian::Data->new('systemd/init-whitelist');
 
@@ -45,33 +51,56 @@ my $HARDENING_FLAGS = Lintian::Data->new('systemd/hardening-flags');
 # Usual WantedBy= targets
 my $WANTEDBY_WHITELIST = Lintian::Data->new('systemd/wantedby-whitelist');
 
-sub run {
-    my ($pkg, undef, $info) = @_;
+sub setup_installed_files {
+    my ($self) = @_;
+
+    my @timers = grep { m,^lib/systemd/system/[^\/]+\.timer$, }
+      $self->processable->installed->sorted_list;
+    $self->_set_timers(\@timers);
+
+    return;
+}
+
+sub visit_installed_files {
+    my ($self, $file) = @_;
+
+    $self->hint('missing-systemd-timer-for-cron-script', $file)
+      if $file->dirname =~ m,^etc/cron\.[^\/]+/$, && !scalar @{$self->timers};
+
+    return;
+}
+
+sub installable {
+    my ($self) = @_;
+
+    my $pkg = $self->processable->name;
+    my $processable = $self->processable;
 
     # non-service checks
-    if (my $tmpfiles = $info->index_resolved_path('etc/tmpfiles.d/')) {
-        for my $file ($tmpfiles->children('breadth-first')) {
-            if ($file->basename =~ m,\.conf$,) {
-                tag 'systemd-tmpfiles.d-outside-usr-lib', $file;
+    if (my $tmpfiles= $processable->installed->resolve_path('etc/tmpfiles.d/'))
+    {
+        for my $file ($tmpfiles->descendants) {
+            if ($file->is_file && $file->basename =~ m,\.conf$,) {
+                $self->hint('systemd-tmpfiles.d-outside-usr-lib', $file);
             }
         }
     }
 
-    my @init_scripts = get_init_scripts($info);
-    my @service_files = get_systemd_service_files($pkg, $info);
+    my @init_scripts = $self->get_init_scripts;
+    my @service_files = $self->get_systemd_service_files;
 
     # A hash of names reference which are provided by the service files.
     # This includes Alias= directives, so after parsing
     # NetworkManager.service, it will contain NetworkManager and
     # network-manager.
-    my $services = get_systemd_service_names($info, \@service_files);
+    my $services = $self->get_systemd_service_names(\@service_files);
 
     for my $script (@init_scripts) {
-        check_init_script($info, $script, $services);
+        $self->check_init_script($script, $services);
     }
 
-    check_timers($info);
-    check_maintainer_scripts($info);
+    $self->check_maintainer_scripts();
+    $self->check_systemd_socket_files();
 
     return;
 }
@@ -85,9 +114,14 @@ sub get_init_service_name {
 }
 
 sub get_init_scripts {
-    my ($info) = @_;
+    my ($self) = @_;
+
+    my $processable = $self->processable;
+
     my @scripts;
-    if (my $initd_path = $info->index_resolved_path('etc/init.d/')) {
+    if ($processable->name ne 'initscripts'
+        and my $initd_path
+        = $processable->installed->resolve_path('etc/init.d/')){
         for my $init_script ($initd_path->children) {
             # sysv generator drops the .sh suffix
             my $basename = get_init_service_name($init_script);
@@ -105,7 +139,9 @@ sub get_init_scripts {
 # Verify that each init script includes /lib/lsb/init-functions,
 # because that is where the systemd diversion happens.
 sub check_init_script {
-    my ($info, $file, $services) = @_;
+    my ($self, $file, $services) = @_;
+
+    my $processable = $self->processable;
     my $basename = $file->basename;
     my $servicename = get_init_service_name($file);
     my $lsb_source_seen;
@@ -113,13 +149,16 @@ sub check_init_script {
 
     if (!$file->is_regular_file) {
         unless ($file->is_open_ok) {
-            tag 'init-script-is-not-a-file', $file;
+            $self->hint('init-script-is-not-a-file', $file);
             return;
         }
     }
-    my $fh = $file->open;
+    open(my $fh, '<', $file->unpacked_path);
     while (<$fh>) {
-        lstrip;
+
+        # trim left
+        s/^\s+//;
+
         $lsb_source_seen = 1
           if $. == 1
           and m{\A [#]! \s* (?:/usr/bin/env)? \s* /lib/init/init-d-script}xsm;
@@ -134,18 +173,21 @@ sub check_init_script {
     }
     close($fh);
 
-    tag 'init.d-script-does-not-source-init-functions', $file
+    $self->hint('init.d-script-does-not-source-init-functions', $file)
       unless $lsb_source_seen;
 
     if (!$services->{$servicename}) {
         # rcS scripts are particularly bad; always tag
         if ($is_rcs_script) {
-            tag 'missing-systemd-service-for-init.d-rcS-script', $basename;
+            $self->hint('missing-systemd-service-for-init.d-rcS-script',
+                $basename);
         } else {
             if (%{$services}) {
-                tag 'omitted-systemd-service-for-init.d-script', $basename;
+                $self->hint('omitted-systemd-service-for-init.d-script',
+                    $basename);
             } else {
-                tag 'missing-systemd-service-for-init.d-script', $basename;
+                $self->hint('missing-systemd-service-for-init.d-script',
+                    $basename);
             }
         }
     }
@@ -154,19 +196,25 @@ sub check_init_script {
 }
 
 sub get_systemd_service_files {
-    my ($pkg, $info) = @_;
+    my ($self) = @_;
+
+    my $pkg = $self->processable->name;
+    my $processable = $self->processable;
     my @res;
     my @potential
-      = grep { m,/systemd/system/.*\.service$, } $info->sorted_index;
+      = grep { m,/systemd/system/.*\.service$, }
+      $processable->installed->sorted_list;
 
     for my $file (@potential) {
-        push(@res, $file) if check_systemd_service_file($pkg, $info, $file);
+        push(@res, $file) if $self->check_systemd_service_file($file);
     }
     return @res;
 }
 
 sub get_systemd_service_names {
-    my ($info,$files_ref) = @_;
+    my ($self,$files_ref) = @_;
+
+    my $processable = $self->processable;
     my %services;
 
     my $safe_add_service = sub {
@@ -183,10 +231,11 @@ sub get_systemd_service_names {
         $name =~ s/@?\.service$//;
         $safe_add_service->($name);
 
-        my @aliases= extract_service_file_values($file, 'Install', 'Alias', 1);
+        my @aliases
+          = $self->extract_service_file_values($file, 'Install', 'Alias');
 
         for my $alias (@aliases) {
-            tag 'systemd-service-alias-without-extension', $file
+            $self->hint('systemd-service-alias-without-extension', $file)
               if $alias !~ m/\.service$/;
             $alias =~ s/\.service$//;
             $safe_add_service->($alias);
@@ -196,78 +245,104 @@ sub get_systemd_service_names {
 }
 
 sub check_systemd_service_file {
-    my ($pkg, $info, $file) = @_;
+    my ($self, $file) = @_;
 
-    tag 'systemd-service-file-outside-lib', $file
+    my $pkg = $self->processable->name;
+    my $processable = $self->processable;
+
+    $self->hint('systemd-service-file-outside-lib', $file)
       if ($file =~ m,^etc/systemd/system/,);
-    tag 'systemd-service-file-outside-lib', $file
+    $self->hint('systemd-service-file-outside-lib', $file)
       if ($file =~ m,^usr/lib/systemd/system/,);
 
     unless ($file->is_open_ok
         || ($file->is_symlink && $file->link eq '/dev/null')) {
-        tag 'service-file-is-not-a-file', $file;
+        $self->hint('service-file-is-not-a-file', $file);
         return 0;
     }
-    my @values = extract_service_file_values($file, 'Unit', 'After');
+    my @values = $self->extract_service_file_values($file, 'Unit', 'After');
     my @obsolete = grep { /^(?:syslog|dbus)\.target$/ } @values;
-    tag 'systemd-service-file-refers-to-obsolete-target', $file, $_
+    $self->hint('systemd-service-file-refers-to-obsolete-target',$file, $_)
       for @obsolete;
 
-    tag 'systemd-service-file-refers-to-obsolete-bindto', $file,
-      if extract_service_file_values($file, 'Unit', 'BindTo', 1);
+    $self->hint('systemd-service-file-refers-to-obsolete-bindto', $file,)
+      if $self->extract_service_file_values($file, 'Unit', 'BindTo');
 
     for my $key (
         qw(ExecStart ExecStartPre ExecStartPost ExecReload ExecStop ExecStopPost)
     ) {
-        tag 'systemd-service-file-wraps-init-script', $file, $key
+        $self->hint('systemd-service-file-wraps-init-script', $file, $key)
           if any { m,^/etc/init\.d/, }
-        extract_service_file_values($file, 'Service', $key, 1);
+        $self->extract_service_file_values($file, 'Service', $key);
     }
 
     if (not $file->is_symlink or $file->link ne '/dev/null') {
-        #<<< no perltidy
+
         my @wanted_by
-          = extract_service_file_values($file, 'Install', 'WantedBy', 1);
-        my $is_oneshot =
-           any { /^oneshot$/ }
-           extract_service_file_values($file, 'Service', 'Type', 1);
-        #>>>
+          = $self->extract_service_file_values($file, 'Install', 'WantedBy');
+        my $is_oneshot =any { /^oneshot$/ }
+        $self->extract_service_file_values($file, 'Service', 'Type');
+
+        # We are a "standalone" service file if we have no .path or .timer
+        # equivalent.
+        my $is_standalone = 1;
+        if ($file =~ m,lib/systemd/system/([^/]*?)@?\.service,) {
+            my $service = $1;
+            for my $x (qw(path timer)) {
+                $is_standalone = 0
+                  if $processable->installed->resolve_path(
+                    "lib/systemd/system/${service}.${x}");
+            }
+        }
+
         foreach my $target (@wanted_by) {
-            tag 'systemd-service-file-refers-to-unusual-wantedby-target',
-              $file, $target
+            $self->hint(
+                'systemd-service-file-refers-to-unusual-wantedby-target',
+                $file, $target)
               unless any { $target eq $_ } $WANTEDBY_WHITELIST->all
               or $pkg eq 'systemd';
         }
-        tag 'systemd-service-file-missing-documentation-key', $file,
-          unless extract_service_file_values($file, 'Unit', 'Documentation',1);
-        tag 'systemd-service-file-missing-install-key', $file,
-             unless @wanted_by
-          or extract_service_file_values($file, 'Install', 'RequiredBy',1)
-          or extract_service_file_values($file, 'Install', 'Also',1)
+        $self->hint('systemd-service-file-missing-documentation-key', $file,)
+          unless $self->extract_service_file_values($file, 'Unit',
+            'Documentation');
+
+        $self->hint('systemd-service-file-missing-install-key', $file,)
+          unless @wanted_by
+          or$self->extract_service_file_values($file, 'Install', 'RequiredBy')
+          or $self->extract_service_file_values($file, 'Install', 'Also')
           or $is_oneshot
+          or not $is_standalone
+          or $file !~ m,^lib/systemd/[^\/]+/[^\/]+\.service$,
           or $file =~ m,@\.service$,;
-        my @pidfile = extract_service_file_values($file,'Service','PIDFile',1);
+
+        my @pidfile
+          = $self->extract_service_file_values($file,'Service','PIDFile');
         foreach my $x (@pidfile) {
-            tag 'systemd-service-file-pidfile-refers-to-var-run', $file, $x
+            $self->hint('systemd-service-file-refers-to-var-run',
+                $file, 'PIDFile', $x)
               if $x =~ m,^/var/run/,;
         }
         my $seen_hardening;
         foreach my $x ($HARDENING_FLAGS->all) {
-            next unless extract_service_file_values($file, 'Service', $x, 1);
+            next
+              unless $self->extract_service_file_values($file, 'Service', $x);
             $seen_hardening = 1;
             last;
         }
-        tag 'systemd-service-file-missing-hardening-features', $file
+        $self->hint('systemd-service-file-missing-hardening-features', $file)
           unless $seen_hardening
           or $is_oneshot
           or any { 'sleep.target' eq $_ } @wanted_by;
 
-        #<<< no perltidy
-        if (extract_service_file_values($file, 'Unit', 'DefaultDependencies', 1)) {
-        #>>>
+        if (
+            $self->extract_service_file_values(
+                $file, 'Unit', 'DefaultDependencies', 1
+            )
+        ) {
+
             my $seen_conflicts_shutdown = 0;
             my @conflicts
-              = extract_service_file_values($file, 'Unit','Conflicts', 1);
+              = $self->extract_service_file_values($file, 'Unit','Conflicts');
             foreach my $x (@conflicts) {
                 next unless $x eq 'shutdown.target';
                 $seen_conflicts_shutdown = 1;
@@ -276,16 +351,44 @@ sub check_systemd_service_file {
             if ($seen_conflicts_shutdown) {
                 my $seen_before_shutdown = 0;
                 my @before
-                  = extract_service_file_values($file, 'Unit','Before', 1);
+                  = $self->extract_service_file_values($file, 'Unit','Before');
                 foreach my $x (@before) {
                     next unless $x eq 'shutdown.target';
                     $seen_before_shutdown = 1;
                     last;
                 }
-                tag 'systemd-service-file-shutdown-problems', $file,
+                $self->hint('systemd-service-file-shutdown-problems', $file,)
                   unless $seen_before_shutdown;
             }
         }
+
+        my %bad_users = (
+            'User' => 'nobody',
+            'Group' => 'nogroup',
+        );
+        while ((my $key, my $value) = each(%bad_users)) {
+            if (
+                any { $_ eq $value }
+                $self->extract_service_file_values($file, 'Service',$key)
+            ) {
+                $self->hint('systemd-service-file-uses-nobody-or-nogroup',
+                    $file, "$key=$value");
+            }
+        }
+
+        foreach my $key (qw(StandardError StandardOutput)) {
+            foreach my $value (qw(syslog syslog-console)) {
+                if (
+                    any { $_ eq $value }
+                    $self->extract_service_file_values($file, 'Service',$key)
+                ) {
+                    $self->hint(
+                        'systemd-service-file-uses-deprecated-syslog-facility',
+                        $file, "$key=$value"
+                    );
+                }
+            }
+        }
     }
 
     return 1;
@@ -296,7 +399,7 @@ sub service_file_lines {
     my (@lines, $continuation);
     return if $path->is_symlink and $path->link eq '/dev/null';
 
-    my $fh = $path->open;
+    open(my $fh, '<', $path->unpacked_path);
     while (<$fh>) {
         chomp;
 
@@ -311,7 +414,8 @@ sub service_file_lines {
             next;
         }
 
-        rstrip;
+        # trim right
+        s/\s+$//;
 
         next if $_ eq '';
 
@@ -326,16 +430,12 @@ sub service_file_lines {
 
 # Extracts the values of a specific Key from a .service file
 sub extract_service_file_values {
-    my ($file, $extract_section, $extract_key, $skip_tag) = @_;
+    my ($self, $file, $extract_section, $extract_key) = @_;
 
     my (@values, $section);
 
     my @lines = service_file_lines($file);
-    my $key_ws = first_index { /^[[:alnum:]]+(\s*=\s|\s+=)/ } @lines;
-    if ($key_ws > -1) {
-        tag 'service-key-has-whitespace', $file, 'at line', $key_ws
-          unless $skip_tag;
-    }
+
     if (any { /^\.include / } @lines) {
         my $parent_dir = $file->parent_dir;
         @lines = map {
@@ -381,53 +481,56 @@ sub extract_service_file_values {
     return @values;
 }
 
-sub check_timers {
-    my ($info) = @_;
-
-    return
-      if any { m,^lib/systemd/system/[^\/]+\.timer$, } $info->sorted_index;
-
-    for my $file ($info->sorted_index) {
-        tag 'missing-systemd-timer-for-cron-script', $file
-          if $file->dirname =~ m,^etc/cron\.[^\/]+/$,;
-    }
-
-    return;
-}
-
 sub check_maintainer_scripts {
-    my ($info) = @_;
+    my ($self) = @_;
 
-    open(my $fd, '<', $info->lab_data_path('control-scripts'));
+    # get maintainer scripts
+    my @control
+      = grep { $_->is_control } $self->processable->control->sorted_list;
 
-    while (<$fd>) {
-        m/^(\S*) (.*)$/
-          or internal_error("bad line in control-scripts file: $_");
-        my $interpreter = $1;
-        my $file = $2;
-        my $path = $info->control_index_resolved_path($file);
+    for my $file (@control) {
+
+        # skip anything but shell scripts
+        my $interpreter = $file->control->{interpreter};
+        next
+          unless $interpreter =~ m/sh\b/;
 
         # Don't follow unsafe links
-        next if not $path or not $path->is_open_ok;
-        # Don't try to parse the file if it does not appear to be a
-        # shell script
-        next if $interpreter !~ m/sh\b/;
+        next
+          unless $file->is_open_ok;
 
-        my $sfd = $path->open;
+        open(my $sfd, '<', $file->unpacked_path);
         while (<$sfd>) {
             # skip comments
             next if substr($_, 0, $-[0]) =~ /#/;
 
             # systemctl should not be called in maintainer scripts at all,
-            # except for systemctl --daemon-reload calls.
+            # except for systemctl daemon-reload calls.
             if (m/^(?:.+;)?\s*systemctl\b/ && !/daemon-reload/) {
-                tag 'maintainer-script-calls-systemctl', "$file:$.";
+                $self->hint('maintainer-script-calls-systemctl', "$file:$.");
             }
         }
         close($sfd);
     }
 
-    close($fd);
+    return;
+}
+
+sub check_systemd_socket_files {
+    my ($self) = @_;
+
+    my @files = $self->processable->installed->sorted_list;
+
+    foreach my $file (grep { m,/systemd/system/.*\.socket$, } @files) {
+        my @xs
+          = $self->extract_service_file_values($file,'Socket','ListenStream');
+        foreach my $x (@xs) {
+            $self->hint('systemd-service-file-refers-to-var-run',
+                $file, 'ListenStream', $x)
+              if $x =~ m,^/var/run/,;
+        }
+    }
+
     return;
 }
 
