@@ -1,7 +1,8 @@
 # -*- perl -*-
 # Lintian::Data -- interface to query lists of keywords
 
-# Copyright (C) 2008 Russ Allbery
+# Copyright © 2008 Russ Allbery
+# Copyright © 2017-2018 Chris Lamb <lamby@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the Free
@@ -26,14 +27,12 @@ use autodie;
 use Carp qw(croak confess);
 use POSIX qw(ENOENT);
 
-use Lintian::Util qw(strip);
-
 our $LAZY_LOAD = 1;
 
 sub _checked_open {
     my ($path) = @_;
     my $fd;
-    eval {open($fd, '<', $path);};
+    eval {open($fd, '<:encoding(UTF-8)', $path);};
     if (my $err = $@) {
         die($err) if not ref $err or $err->errno != ENOENT;
         return;
@@ -157,7 +156,10 @@ sub _parse_file {
     $filename = $vendors->[$vno] . '/' . $data_name if $vno < scalar @$vendors;
     local $.;
     while (my $line = <$fd>) {
-        strip($line);
+
+        # trim both ends
+        $line =~ s/^\s+|\s+$//g;
+
         next if $line =~ m{ \A \#}xsm or $line eq '';
         if ($line =~ s/^\@//) {
             my ($op, $value) = split(m{ \s++ }xsm, $line, 2);
