@@ -24,28 +24,24 @@ use warnings;
 use utf8;
 use autodie;
 
-use Carp;
-use Cwd;
+use Carp qw(croak);
 use Devel::Size qw(total_size);
 use File::Spec;
 use List::Compare;
-use List::MoreUtils qw(uniq firstval);
+use List::MoreUtils qw(none uniq firstval);
 use Path::Tiny;
 use POSIX qw(ENOENT);
 use Time::HiRes qw(gettimeofday tv_interval);
+use Time::Piece;
 
-use Lintian::Processable::Binary;
+use Lintian::Processable::Installable;
 use Lintian::Processable::Buildinfo;
 use Lintian::Processable::Changes;
 use Lintian::Processable::Source;
-use Lintian::Processable::Udeb;
-use Lintian::Util qw(get_dsc_info strip human_bytes);
+use Lintian::Util qw(human_bytes);
 
 use constant EMPTY => q{};
 use constant SPACE => q{ };
-use constant HYPHEN => q{-};
-use constant SLASH => q{/};
-use constant UNDERSCORE => q{_};
 
 use Moo;
 use namespace::clean;
@@ -115,6 +111,10 @@ Returns or sets the max number of jobs to be processed in parallel.
 If the limit is 0, then there is no limit for the number of parallel
 jobs.
 
+=item processing_start
+
+=item processing_end
+
 =item cache
 
 Cache for some items.
@@ -127,10 +127,6 @@ Hash with active jobs.
 
 =item C<saved_direct_reliants>
 
-=item C<saved_spelling_exceptions>
-
-=item C<shared_storage>
-
 =cut
 
 has pooldir => (is => 'rw', default => EMPTY);
@@ -143,23 +139,17 @@ has source => (is => 'rw');
 has udeb => (is => 'rw', default => sub{ {} });
 
 has jobs => (is => 'rw', default => 1);
+has processing_start => (is => 'rw', default => EMPTY);
+has processing_end => (is => 'rw', default => EMPTY);
 
 has cache => (is => 'rw', default => sub { {} });
 has profile => (is => 'rw', default => sub { {} });
 
-has saved_direct_dependencies => (is => 'rw', default => sub { {} });
-has saved_direct_reliants => (is => 'rw', default => sub { {} });
-has saved_spelling_exceptions => (is => 'rw', default => sub { {} });
-
-has shared_storage => (is => 'rw', default => sub { {} });
-
-=item Lintian::Group->init_from_file (FILE)
-
-Add all processables from .changes or .buildinfo file FILE.
+=item add_processable_from_file
 
 =cut
 
-sub _get_processable {
+sub add_processable_from_file {
     my ($self, $file) = @_;
 
     my $absolute = path($file)->realpath->stringify;
@@ -168,20 +158,22 @@ sub _get_processable {
 
     my $processable;
 
-    if ($file =~ m/\.dsc$/o) {
+    if ($file =~ /\.dsc$/) {
         $processable = Lintian::Processable::Source->new;
 
-    } elsif ($file =~ m/\.buildinfo$/o) {
+    } elsif ($file =~ /\.buildinfo$/) {
         $processable = Lintian::Processable::Buildinfo->new;
 
-    } elsif ($file =~ m/\.d?deb$/) {
+    } elsif ($file =~ /\.d?deb$/) {
         # in ubuntu, automatic dbgsym packages end with .ddeb
-        $processable = Lintian::Processable::Binary->new;
+        $processable = Lintian::Processable::Installable->new;
+        $processable->type('binary');
 
-    } elsif ($file =~ m/\.udeb$/o) {
-        $processable = Lintian::Processable::Udeb->new;
+    } elsif ($file =~ /\.udeb$/) {
+        $processable = Lintian::Processable::Installable->new;
+        $processable->type('udeb');
 
-    } elsif ($file =~ m/\.changes$/o) {
+    } elsif ($file =~ /\.changes$/) {
         $processable = Lintian::Processable::Changes->new;
 
     } else {
@@ -191,114 +183,9 @@ sub _get_processable {
     $processable->pooldir($self->pooldir);
     $processable->init($absolute);
 
-    return $processable;
-}
-
-#  populates $self from a buildinfo or changes file.
-sub init_from_file {
-    my ($self, $path) = @_;
-
-    return
-      unless defined $path;
-
-    my $processable = $self->_get_processable($path);
     $self->add_processable($processable);
 
-    my ($type) = $path =~ m/\.(buildinfo|changes)$/;
-    return
-      unless defined $type;
-
-    my $info = get_dsc_info($path)
-      or die "$path is not a valid $type file";
-
-    my $dir = $path;
-    if ($path =~ m,^/+[^/]++$,o){
-        # it is "/files.changes?"
-        #  - In case you were wondering, we were told not to ask :)
-        #   See #624149
-        $dir = '/';
-    } else {
-        # it is "<something>/files.changes"
-        $dir =~ s,(.+)/[^/]+$,$1,;
-    }
-    my $key = $type eq 'buildinfo' ? 'checksums-sha256' : 'files';
-    for my $line (split(/\n/o, $info->{$key}//'')) {
-
-        next
-          unless defined $line;
-
-        strip($line);
-
-        next
-          if $line eq EMPTY;
-
-        # Ignore files that may lead to path traversal issues.
-
-        # We do not need (eg.) md5sum, size, section or priority
-        # - just the file name please.
-        my $file = (split(/\s+/, $line))[-1];
-
-        # If the field is malformed, $file may be undefined; we also
-        # skip it, if it contains a "/" since that is most likely a
-        # traversal attempt
-        next
-          if !$file || $file =~ m,/,;
-
-        unless (-f "$dir/$file") {
-            print STDERR "$dir/$file does not exist, exiting\n";
-            exit 2;
-        }
-
-        # only care about some files; ddeb is ubuntu dbgsym
-        next
-          unless $file =~ /\.(?:u|d)?deb$/
-          || $file =~ m/\.dsc$/
-          || $file =~ m/\.buildinfo$/;
-
-        my $payload = $self->_get_processable("$dir/$file");
-        $self->add_processable($payload);
-    }
-
-    return 1;
-}
-
-=item unpack
-
-Unpack this group.
-
-=cut
-
-sub unpack {
-    my ($self, $OUTPUT)= @_;
-
-    my @processables = $self->get_processables;
-    for my $processable (@processables) {
-
-        $processable->create;
-
-        # for sources pull in all related files so unpacked does not fail
-        if ($processable->type eq 'source') {
-            my (undef, $dir, undef)= File::Spec->splitpath($processable->path);
-            for my $fs (split(m/\n/o, $processable->field('files'))) {
-                strip($fs);
-                next if $fs eq '';
-                my @t = split(/\s+/o,$fs);
-                next if ($t[2] =~ m,/,o);
-                symlink("$dir/$t[2]", $processable->groupdir . "/$t[2]")
-                  or croak("cannot symlink file $t[2]: $!");
-            }
-        }
-    }
-
-    $OUTPUT->v_msg('Unpacking packages in group ' . $self->name);
-
-    my @unpack = grep { $_->can('unpack') } @processables;
-
-    my $savedir = getcwd;
-    $_->unpack for @unpack;
-    chdir($savedir);
-
-    return;
+    return $processable;
 }
 
 =item process
@@ -308,33 +195,27 @@ Process group.
 =cut
 
 sub process {
-    my ($self, $exit_code_ref, $override_count, $opt, $OUTPUT)= @_;
+    my ($self, $ignored_overrides, $option, $OUTPUT)= @_;
 
-    my $all_ok = 1;
+    my $groupname = $self->name;
+    local $SIG{__WARN__} = sub { warn "Warning in group $groupname: $_[0]" };
 
+    $self->processing_start(gmtime->datetime . 'Z');
+    $OUTPUT->v_msg('Starting on group ' . $self->name);
     my $timer = [gettimeofday];
 
-    my %statistics = (
-        types     => {},
-        severity  => {},
-        tags      => {},
-        overrides => {},
-    );
-
-    my @reported_tags;
-
+    my $success = 1;
     for my $processable ($self->get_processables){
 
-        my $declared_overrides;
-        my %used_overrides;
+        # needed to read tag specifications
+        $processable->profile($self->profile);
 
-        # to store tag names as well
-        my $override_count->{ignored} = {};
+        my $declared_overrides;
 
         $OUTPUT->debug_msg(1,
-            'Base directory for group: ' . $processable->groupdir);
+            'Base directory for processable: ' . $processable->basedir);
 
-        unless ($opt->{'no-override'}) {
+        unless ($option->{'no-override'}) {
 
             $OUTPUT->debug_msg(1, 'Loading overrides file (if any) ...');
 
@@ -344,30 +225,64 @@ sub process {
             }
 
             my %alias = %{$self->profile->known_aliases};
+            my @renamed_overrides
+              = grep { length $alias{$_} } keys %{$declared_overrides};
 
             # treat renamed tags in overrides
-            for my $tagname (keys %{$declared_overrides}) {
+            for my $dated (@renamed_overrides) {
 
-                # use new name if tag was renamed
-                my $current = $alias{$tagname};
+                # get new name
+                my $modern = $alias{$dated};
 
-                next
-                  unless defined $current;
+                # make space for renamed override
+                $declared_overrides->{$modern} //= {};
 
-                unless ($current eq $tagname) {
+                for my $context (keys %{$declared_overrides->{$dated}}) {
 
-                    $processable->tag('renamed-tag',
-                        "$tagname => $current at line "
-                          .$declared_overrides->{$tagname}{$_}{line})
-                      for keys %{$declared_overrides->{$tagname}};
+                    # alert user to new tag name
+                    $processable->hint('renamed-tag',
+                        "$dated => $modern in line "
+                          .$declared_overrides->{$dated}{$context}{line});
 
-                    $declared_overrides->{$current} //= {};
-                    $declared_overrides->{$current}{$_}
-                      = $declared_overrides->{$tagname}{$_}
-                      for keys %{$declared_overrides->{$tagname}};
+                    if (exists $declared_overrides->{$modern}{$context}) {
 
-                    delete $declared_overrides->{$tagname};
+                        my @lines = (
+                            $declared_overrides->{$dated}{$context}{line},
+                            $declared_overrides->{$modern}{$context}{line});
+                        $processable->hint('duplicate-override-context',
+                            $modern, 'lines', sort @lines);
+
+                        next;
+                    }
+
+                    # transfer context to current tag name
+                    $declared_overrides->{$modern}{$context}
+                      = $declared_overrides->{$dated}{$context};
+
+                    # remember old tagname
+                    $declared_overrides->{$modern}{$context}{'renamed-from'}
+                      = $dated;
+
+                    # remove the old override context
+                    delete $declared_overrides->{$dated}{$context};
                 }
+
+                # remove the alias override if there are no contexts left
+                delete $declared_overrides->{$dated}
+                  unless %{$declared_overrides->{$dated}};
+            }
+
+            # complain about and filter out unknown tags in overrides
+            my @unknown_overrides = grep { !$self->profile->get_tag($_) }
+              keys %{$declared_overrides};
+            for my $tagname (@unknown_overrides) {
+
+                $processable->hint('malformed-override',
+                    "Unknown tag $tagname in line "
+                      . $declared_overrides->{$tagname}{$_}{line})
+                  for keys %{$declared_overrides->{$tagname}};
+
+                delete $declared_overrides->{$tagname};
             }
 
             # treat ignored overrides here
@@ -375,23 +290,15 @@ sub process {
 
                 unless ($self->profile->is_overridable($tagname)) {
                     delete $declared_overrides->{$tagname};
-                    $override_count->{ignored}{$tagname}++;
+                    $ignored_overrides->{$tagname}++;
                 }
             }
-
-            for my $tagname (keys %{$declared_overrides}) {
-
-                my $hints = $declared_overrides->{$tagname};
-
-                # set the use count to zero for each hint
-                $used_overrides{$tagname}{$_} = 0 for keys %{$hints};
-            }
         }
 
         # Filter out the "lintian" check if present - it does no real harm,
         # but it adds a bit of noise in the debug output.
         my @checknames
-          = grep { $_ ne 'lintian' } $self->profile->enabled_checks;
+          = sort grep { $_ ne 'lintian' } $self->profile->enabled_checks;
         my @checkinfos = map { $self->profile->get_checkinfo($_) } @checknames;
 
         for my $checkinfo (@checkinfos) {
@@ -412,184 +319,99 @@ sub process {
             my $raw_res = tv_interval($timer);
 
             if ($err) {
-                print STDERR $err;
-                print STDERR "internal error: cannot run $checkname check",
-                  " on package $procid\n";
-                $OUTPUT->warning("skipping check of $procid");
-                $$exit_code_ref = 2;
-                $all_ok = 0;
+                my $message = $err;
+                $message
+                  .= "warning: cannot run $checkname check on package $procid\n";
+                $message .= "skipping check of $procid\n";
+                warn $message;
+
+                $success = 0;
 
                 next;
             }
+
             my $tres = sprintf('%.3fs', $raw_res);
             $OUTPUT->debug_msg(1,
                 "Check script $checkname for $procid done ($tres)");
             $OUTPUT->perf_log("$procid,check/$checkname,${raw_res}");
         }
 
-        my $knownlc
-          = List::Compare->new([map { $_->name } @{$processable->tags}],
-            [$self->profile->known_tags]);
-        my @unknown_tagnames = $knownlc->get_Lonly;
-        croak 'tried to issue unknown tags: ' . join(SPACE, @unknown_tagnames)
-          if @unknown_tagnames;
+        my %used_overrides;
 
-        # remove disabled tags
-        my @enabled_tags
-          = grep { $self->profile->tag_is_enabled($_->name) }
-          @{$processable->tags};
-        $processable->tags(\@enabled_tags);
+        my @keep_hints;
+        for my $hint (@{$processable->hints}) {
 
-        my @keep_tags;
-        for my $tag (@{$processable->tags}) {
-
-            my $override;
-
-            my $tag_overrides= $declared_overrides->{$tag->name};
-            if ($tag_overrides) {
+            my $declared = $declared_overrides->{$hint->tag->name};
+            if ($declared && !$hint->tag->show_always) {
 
                 # do not use EMPTY; hash keys literal
-                # empty hint in specification matches all
-                $override = $tag_overrides->{''};
+                # empty context in specification matches all
+                my $override = $declared->{''};
 
-                # matches hint exactly
-                $override = $tag_overrides->{$tag->hint}
+                # matches context exactly
+                $override = $declared->{$hint->context}
                   unless $override;
 
                 # look for patterns
                 unless ($override) {
                     my @candidates
-                      = sort grep { length $tag_overrides->{$_}{pattern} }
-                      keys %{$tag_overrides};
+                      = sort grep { length $declared->{$_}{pattern} }
+                      keys %{$declared};
 
                     my $match= firstval {
-                        $tag->hint =~ m/^$tag_overrides->{$_}{pattern}\z/
+                        $hint->context =~ m/^$declared->{$_}{pattern}\z/
                     }
                     @candidates;
 
-                    $override = $tag_overrides->{$match}
+                    $override = $declared->{$match}
                       if $match;
                 }
 
-                $used_overrides{$tag->name}{$override->{hint}}++
+                # new hash keys are autovivified to 0
+                $used_overrides{$hint->tag->name}{$override->{context}}++
                   if $override;
+
+                $hint->override($override);
             }
 
-            $tag->override($override);
-
-            push(@keep_tags, $tag);
+            push(@keep_hints, $hint);
         }
 
-        $processable->tags(\@keep_tags);
+        $processable->hints(\@keep_hints);
+
+        my %otherwise_visible = map { $_->tag->name => 1 } @keep_hints;
 
         # look for unused overrides
-        # should this not iterate over $tag_overrides instead?
-        for my $tagname (keys %used_overrides) {
+        for my $tagname (keys %{$declared_overrides}) {
 
             next
               unless $self->profile->tag_is_enabled($tagname);
 
-            my $tag_overrides = $used_overrides{$tagname};
+            my @declared_contexts = keys %{$declared_overrides->{$tagname}};
+            my @used_contexts = keys %{$used_overrides{$tagname} // {}};
 
-            for my $hint (keys %{$tag_overrides}) {
+            my $context_lc
+              = List::Compare->new(\@declared_contexts, \@used_contexts);
+            my @unused_contexts = $context_lc->get_Lonly;
 
-                next
-                  if $tag_overrides->{$hint};
+            # cannot be overridden or suppressed
+            my $condition = 'unused-override';
+            $condition = 'mismatched-override'
+              if $otherwise_visible{$tagname};
 
-                # cannot be overridden or suppressed
-                $processable->tag('unused-override', $tagname, $hint);
+            for my $context (@unused_contexts) {
 
-                $override_count->{unused}++;
+                # for renames, use the original name from overrides
+                my $original_name
+                  = $declared_overrides->{$tagname}{$context}{'renamed-from'}
+                  // $tagname;
+
+                $processable->hint($condition, $original_name, $context);
             }
         }
-
-        # associate all tags with processable
-        $_->processable($processable) for @{$processable->tags};
-
-        push(@reported_tags, @{$processable->tags});
-
-        # remove circular references
-        $processable->tags([]);
     }
 
-    # copy tag specifications into tags
-    $_->info($self->profile->get_taginfo($_->name)) for @reported_tags;
-
-    for my $tag (@reported_tags) {
-
-        my $record = \%statistics;
-        $record = $statistics{overrides}
-          if $tag->override;
-
-        $record->{tags}{$tag->name}++;
-        $record->{severity}{$tag->info->effective_severity}++;
-
-        my $code = $tag->info->code;
-        $code = 'X' if $tag->info->experimental;
-        $record->{types}{$code}++;
-    }
-
-    unless ($$exit_code_ref) {
-        if ($statistics{types}{E}) {
-            $$exit_code_ref = 1;
-        }
-    }
-
-    # Report override statistics.
-    unless ($opt->{'no-override'} || $opt->{'show-overrides'}) {
-
-        my $errors = $statistics{overrides}{types}{E} // 0;
-        my $warnings = $statistics{overrides}{types}{W} // 0;
-        my $info = $statistics{overrides}{types}{I} // 0;
-
-        $override_count->{errors} += $errors;
-        $override_count->{warnings} += $warnings;
-        $override_count->{info} += $info;
-    }
-
-    # discard disabled tags
-    @reported_tags
-      = grep { $self->profile->tag_is_enabled($_->name) } @reported_tags;
-
-    # discard experimental tags
-    @reported_tags = grep { !$_->info->experimental } @reported_tags
-      unless $opt->{'display-experimental'};
-
-    # discard overridden tags
-    @reported_tags = grep { !defined $_->override } @reported_tags
-      unless $opt->{'show-overrides'};
-
-    # discard outside the selected display level
-    @reported_tags
-      = grep { $self->profile->display_level_for_tag($_->name) }@reported_tags;
-
-    my $reference_limit = $opt->{'display-source'} // [];
-    if (@{$reference_limit}) {
-
-        my @topic_tags;
-        for my $tag (@reported_tags) {
-            my @references = split(/,/, $tag->info->references);
-
-            # retain the first word
-            s/^([\w-]+)\s.*/$1/ for @references;
-
-            # remove anything in parentheses at the end
-            s/\(\S+\)$// for @references;
-
-            # check if tag refers to the selected references
-            my $referencelc
-              = List::Compare->new(\@references, $reference_limit);
-            next
-              unless $referencelc->get_intersection;
-
-            push(@topic_tags, $tag);
-        }
-
-        @reported_tags = @topic_tags;
-    }
-
-    # put tags back into their respective processables
-    push(@{$_->processable->tags}, $_) for @reported_tags;
+    $self->processing_end(gmtime->datetime . 'Z');
 
     my $raw_res = tv_interval($timer);
     my $tres = sprintf('%.3fs', $raw_res);
@@ -597,7 +419,7 @@ sub process {
         'Checking all of group ' . $self->name . " done ($tres)");
     $OUTPUT->perf_log($self->name . ",total-group-check,${raw_res}");
 
-    if ($opt->{'debug'} > 2) {
+    if ($option->{'debug'} > 2) {
 
         # suppress warnings without reliable sizes
         $Devel::Size::warn = 0;
@@ -617,7 +439,7 @@ sub process {
 
     $self->clean_lab($OUTPUT);
 
-    return $all_ok;
+    return $success;
 }
 
 =item clean_lab
@@ -691,10 +513,6 @@ sub add_processable{
     croak 'Not a supported type (' . $processable->type . ')'
       unless exists $SUPPORTED_TYPES{$processable->type};
 
-    my $dir = $self->_pool_path($processable);
-
-    $processable->groupdir($dir);
-
     if ($processable->type eq 'changes') {
         die 'Cannot add another ' . $processable->type . ' file'
           if $self->changes;
@@ -723,49 +541,9 @@ sub add_processable{
         $self->$type->{$id} = $processable;
     }
 
-    $processable->shared_storage($self->shared_storage);
-
     return 1;
 }
 
-# Given the package meta data (src_name, type, name, version, arch) return the
-# path to it in the Lab.  The path returned will be absolute.
-sub _pool_path {
-    my ($self, $processable) = @_;
-
-    my $dir = $self->pooldir;
-    my $prefix;
-
-    # If it is at least 4 characters and starts with "lib", use "libX"
-    # as prefix
-    if ($processable->source =~ m/^lib./) {
-        $prefix = substr $processable->source, 0, 4;
-    } else {
-        $prefix = substr $processable->source, 0, 1;
-    }
-
-    my $path
-      = $prefix
-      . SLASH
-      . $processable->source
-      . SLASH
-      . $processable->name
-      . UNDERSCORE
-      . $processable->version;
-    $path .= UNDERSCORE . $processable->architecture
-      unless $processable->type eq 'source';
-    $path .= UNDERSCORE . $processable->type;
-
-    # Turn spaces into dashes - spaces do appear in architectures
-    # (i.e. for changes files).
-    $path =~ s/\s/-/go;
-
-    # Also replace ":" with "_" as : is usually used for path separator
-    $path =~ s/:/_/go;
-
-    return "$dir/pool/$path";
-}
-
 =item $group->get_processables([$type])
 
 Returns an array of all processables in $group.  The processables are
@@ -825,16 +603,6 @@ sub get_binary_processables {
     return @result;
 }
 
-=item $group->info
-
-=cut
-
-sub info {
-    my ($self) = @_;
-
-    return $self;
-}
-
 =item direct_dependencies (PROC)
 
 If PROC is a part of the underlying processable group, this method
@@ -848,7 +616,8 @@ Note: Self-dependencies (if any) are I<not> included in the result.
 
 =cut
 
-# sub direct_dependencies Needs-Info <>
+has saved_direct_dependencies => (is => 'rw', default => sub { {} });
+
 sub direct_dependencies {
     my ($self, $processable) = @_;
 
@@ -899,7 +668,8 @@ Note: Self-dependencies (if any) are I<not> included in the result.
 
 =cut
 
-# sub direct_reliants Needs-Info <>
+has saved_direct_reliants => (is => 'rw', default => sub { {} });
+
 sub direct_reliants {
     my ($self, $processable) = @_;
 
@@ -936,20 +706,6 @@ sub direct_reliants {
     return $self->saved_direct_reliants;
 }
 
-=item $ginfo->type
-
-Return the type of this collect object (which is the string 'group').
-
-=cut
-
-# Return the package type.
-# sub type Needs-Info <>
-sub type {
-    my ($self) = @_;
-
-    return 'group';
-}
-
 =item spelling_exceptions
 
 Returns a hashref of words, which the spell checker should ignore.
@@ -960,48 +716,28 @@ Example: Package alot-doc (#687464)
 
 =cut
 
-# sub spelling_exceptions Needs-Info <>
-sub spelling_exceptions {
-    my ($self) = @_;
+has spelling_exceptions => (
+    is => 'rw',
+    lazy => 1,
+    default => sub {
+        my ($self) = @_;
 
-    return $self->saved_spelling_exceptions
-      if keys %{$self->saved_spelling_exceptions};
+        my %exceptions;
 
-    my %exceptions;
+        for my $processable ($self->get_processables) {
 
-    foreach my $processable ($self->get_processables) {
+            my @names = ($processable->name, $processable->source);
+            push(@names, $processable->debian_control->installables)
+              if $processable->type eq 'source';
 
-        my @names = ($processable->name, $processable->source);
-        push(@names, $processable->binaries)
-          if $processable->type eq 'source';
-
-        foreach my $name (@names) {
-            $exceptions{$name} = 1;
-            $exceptions{$_} = 1 for split m/-/, $name;
+            foreach my $name (@names) {
+                $exceptions{$name} = 1;
+                $exceptions{$_} = 1 for split m/-/, $name;
+            }
         }
-    }
 
-    $self->saved_spelling_exceptions(\%exceptions);
-
-    return $self->saved_spelling_exceptions;
-}
-
-=item $group->clear_cache
-
-Discard the info element of all members of this group, so the memory
-used by it can be reclaimed.  Mostly useful when checking a lot of
-packages (e.g. on lintian.d.o).
-
-=cut
-
-sub clear_cache {
-    my ($self) = @_;
-    for my $proc ($self->get_processables) {
-        $proc->clear_cache;
-    }
-
-    return;
-}
+        return \%exceptions;
+    });
 
 =back
 
