@@ -36,7 +36,6 @@ Lintian::Processable::Hardening - access to collected hardening data
 =head1 SYNOPSIS
 
     use Lintian::Processable;
-    my $processable = Lintian::Processable::Binary->new;
 
 =head1 DESCRIPTION
 
@@ -61,7 +60,7 @@ sub hardening_info {
     return $self->{hardening_info}
       if exists $self->{hardening_info};
 
-    my $hardf = path($self->groupdir)->child('hardening-info')->stringify;
+    my $hardf = path($self->basedir)->child('hardening-info')->stringify;
 
     my %hardening_info;
 
