@@ -24,10 +24,12 @@ use utf8;
 use autodie;
 
 use Carp qw(croak);
+use File::Spec;
 use Path::Tiny;
 
 use Lintian::Deb822::File;
 
+use constant EMPTY => q{};
 use constant COLON => q{:};
 use constant SLASH => q{/};
 
@@ -44,7 +46,7 @@ with 'Lintian::Processable',
   'Lintian::Processable::Orig',
   'Lintian::Processable::Overrides',
   'Lintian::Processable::Patched',
-  'Lintian::Processable::Source::Diffstat',
+  'Lintian::Processable::Source::Components',
   'Lintian::Processable::Source::Format',
   'Lintian::Processable::Source::Relation',
   'Lintian::Processable::Source::Repacked';
@@ -88,9 +90,7 @@ sub init {
       unless -e $file;
 
     $self->path($file);
-
     $self->type('source');
-    $self->link_label('dsc');
 
     my $primary = Lintian::Deb822::File->new;
     my @sections = $primary->read_file($self->path)
@@ -126,24 +126,6 @@ sub init {
     return;
 }
 
-=item unpack
-
-=cut
-
-sub unpack {
-    my ($self) = @_;
-
-    $self->patched->collect($self->groupdir);
-
-    $self->add_diffstat;
-    $self->add_overrides;
-
-    $self->orig->collect($self->groupdir)
-      unless $self->native;
-
-    return;
-}
-
 =back
 
 =head1 AUTHOR
