@@ -1,7 +1,7 @@
 # Hey emacs! This is a -*- Perl -*- script!
 # Lintian::Reporting::Util -- Perl utility functions for lintian's reporting framework
 
-# Copyright (C) 1998 Christian Schwarz
+# Copyright © 1998 Christian Schwarz
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -46,8 +46,9 @@ Most subs are imported only on request.
 
 =cut
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
 
 use Exporter qw(import);
