@@ -1,4 +1,4 @@
-# Copyright © 2018 Felix Lechner
+# Copyright © 2020 Felix Lechner
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,10 +34,10 @@ tests that are supposed to run.
 
 =cut
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
-use v5.10;
 
 use Exporter qw(import);
 
@@ -51,16 +51,15 @@ BEGIN {
 use Carp;
 use File::Spec::Functions qw(rel2abs splitpath catpath);
 use File::Find::Rule;
-use List::Util qw(uniq any all);
+use List::MoreUtils qw(uniq none);
+use List::Util qw(any all);
+use Path::Tiny;
 use Text::CSV;
 
 use Lintian::Profile;
-
 use Test::Lintian::ConfigFile qw(read_config);
 
-use constant TAGS => 'tags';
-
-my @LINTIAN_SUITES = (TAGS);
+my @LINTIAN_SUITES = qw(recipes);
 
 use constant DESC => 'desc';
 use constant TWO_SEPARATED_BY_COLON => qr/([^:]+):([^:]+)/;
@@ -144,6 +143,7 @@ sub find_selected_lintian_testpaths {
         'suite' => [],
         'test' => [],
         'check' => [],
+        'skeleton' => [],
     };
     my @filter_no_prefix;
 
@@ -166,8 +166,8 @@ sub find_selected_lintian_testpaths {
         }
     }
 
-    my $LINTIAN_ROOT = $ENV{'LINTIAN_ROOT'}//die('Cannot find LINTIAN_ROOT');
-    my $profile = Lintian::Profile->new(undef, [$LINTIAN_ROOT]);
+    my $profile = Lintian::Profile->new;
+    $profile->load(undef, [$ENV{LINTIAN_BASE}]);
 
     my @found;
     foreach my $suite (sort @LINTIAN_SUITES) {
@@ -191,32 +191,57 @@ sub find_selected_lintian_testpaths {
 
             my %wanted = map { $_ => 1 } @{$filter->{check}};
 
-            for my $tag (@{$filter->{tag}}) {
-                my $taginfo = $profile->get_tag($tag);
-                unless ($taginfo) {
-                    say "Tag $tag not found";
+            for my $tagname (@{$filter->{tag}}) {
+
+                my $tag = $profile->get_tag($tagname);
+                unless ($tag) {
+                    say "Tag $tagname not found";
                     return;
                 }
-                $wanted{$taginfo->script} = 1;
+
+                if (none { $tagname eq $_ } $profile->enabled_tags) {
+                    say "Tag $tagname not enabled";
+                    return;
+                }
+
+                $wanted{$tag->check} = 1;
             }
 
             for my $testpath (find_all_testpaths($suitepath)) {
-                my $desc = read_config("$testpath/" . DESC);
+                my $desc = read_config("$testpath/eval/" . DESC);
 
-                next unless exists $desc->{check};
+                next
+                  unless $desc->exists('Check');
 
-                foreach my $check (split(SPACE, $desc->{check})) {
+                for my $check ($desc->trimmed_list('Check')) {
                     push(@insuite, $testpath)
                       if exists $wanted{$check};
                 }
             }
         }
 
+        # find tests for selected skeleton
+        if (scalar @{$filter->{skeleton}}) {
+
+            my %wanted = map { $_ => 1 } @{$filter->{skeleton}};
+
+            for my $testpath (find_all_testpaths($suitepath)) {
+                my $desc = read_config("$testpath/build-spec/fill-values");
+
+                next
+                  unless $desc->exists('Skeleton');
+
+                my $skeleton = $desc->unfolded_value('Skeleton');
+                push(@insuite, $testpath)
+                  if exists $wanted{$skeleton};
+            }
+        }
+
         # guess what was meant by selection without prefix
         foreach my $parameter (@filter_no_prefix) {
             push(@insuite,find_testpaths_by_name($suitepath, $parameter));
 
-            my $checkscript = $profile->get_script($parameter);
+            my $checkscript = $profile->get_checkinfo($parameter);
             if ($parameter eq 'legacy' || defined $checkscript) {
                 push(@insuite,
                     find_testpaths_by_name($suitepath, "$parameter-*"));
@@ -241,12 +266,10 @@ sub find_all_testpaths {
     my ($directory) = @_;
     my @descfiles = File::Find::Rule->file()->name(DESC)->in($directory);
 
-    my @testpaths;
-    foreach my $descfile (@descfiles) {
-        my ($volume, $directories, $file) = splitpath($descfile);
-        croak('Filename should be ' . DESC) unless $file eq DESC;
-        push(@testpaths, catpath($volume, $directories, EMPTY));
-    }
+    my @testpaths
+      = map { my $parent = path($_)->parent->parent; $parent->stringify }
+      @descfiles;
+
     return @testpaths;
 }
 
@@ -263,8 +286,8 @@ sub find_testpaths_by_name {
     my ($path, $name) = @_;
 
     my @named = File::Find::Rule->directory()->name($name)->in($path);
-    my @testpaths
-      = grep { defined } map { -f rel2abs(DESC, $_) ? $_ : undef } @named;
+    my @testpaths= grep { defined }
+      map { -f rel2abs('eval/' . DESC, $_) ? $_ : undef } @named;
 
     return @testpaths;
 }
@@ -279,18 +302,19 @@ located in TEST_PATH.
 sub find_all_tags {
     my ($testpath) = @_;
 
-    my $desc = read_config("$testpath/" . DESC);
+    my $desc = read_config("$testpath/eval/" . DESC);
 
-    return EMPTY unless length $desc->{check};
+    return EMPTY
+      unless $desc->exists('Check');
 
     my %tags;
 
-    my $LINTIAN_ROOT = $ENV{'LINTIAN_ROOT'}//die('Cannot find LINTIAN_ROOT');
-    my $profile = Lintian::Profile->new(undef, [$LINTIAN_ROOT]);
+    my $profile = Lintian::Profile->new;
+    $profile->load(undef, [$ENV{LINTIAN_BASE}]);
 
-    my @checks = split(SPACE, $desc->{check});
-    foreach my $check (@checks) {
-        my $checkscript = $profile->get_script($check);
+    my @checks = $desc->trimmed_list('Check');
+    for my $check (@checks) {
+        my $checkscript = $profile->get_checkinfo($check);
         die "Unknown Lintian check $check"
           unless defined $checkscript;
 
@@ -298,12 +322,12 @@ sub find_all_tags {
     }
 
     return keys %tags
-      unless length $desc->{test_against};
+      unless $desc->exists('Test-Against');
 
     # read tags from specification
     my $temp = Path::Tiny->tempfile;
     die "tagextract failed: $!"
-      if system('t/bin/tagextract', '-f', 'EWI', "$testpath/tags",
+      if system('private/tagextract', '-f', 'EWI', "$testpath/tags",
         $temp->stringify);
     my @lines = $temp->lines_utf8({ chomp => 1 });
 
@@ -331,7 +355,7 @@ sub find_all_tags {
     }
 
     # add tags listed in Test-Against
-    my @test_against = split(SPACE, $desc->{test_against});
+    my @test_against = $desc->trimmed_list('Test-Against');
     $tags{$_} = 1 for @test_against;
 
     return keys %tags;
@@ -342,3 +366,9 @@ sub find_all_tags {
 =cut
 
 1;
+
+# Local Variables:
+# indent-tabs-mode: nil
+# cperl-indent-level: 4
+# End:
+# vim: syntax=perl sw=4 sts=4 sr et
