@@ -37,10 +37,10 @@ Routines for dealing with templates in Lintian test specifications.
 
 =cut
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 use autodie;
-use v5.10;
 
 use Exporter qw(import);
 
@@ -175,7 +175,7 @@ sub fill_skeleton_templates {
               . "from templates using whitelist '$name'.";
             my $whitelist = read_config($whitelistpath);
 
-            my @candidates = split(SPACE, $whitelist->{may_generate});
+            my @candidates = $whitelist->trimmed_list('May-Generate');
             my $destination = "$runpath/$relative";
 
             say 'Fill templates'
@@ -225,7 +225,7 @@ sub fill_whitelisted_templates {
       unless -f $whitelistpath;
 
     my $whitelist = read_config($whitelistpath);
-    my @list = split(SPACE, $whitelist->{may_generate});
+    my @list = $whitelist->trimmed_list('May-Generate');
 
     foreach my $file (@list) {
         my $generated = rel2abs($file, $directory);
@@ -277,7 +277,11 @@ sub fill_template {
 
     if ($generated_epoch <= $threshold) {
 
-        my $filler= Text::Template->new(TYPE => 'FILE', SOURCE => $template);
+        my $filler= Text::Template->new(
+            TYPE => 'FILE',
+            DELIMITERS => ['[%', '%]'],
+            SOURCE => $template
+        );
         croak("Cannot read template $template: $Text::Template::ERROR")
           unless $filler;
 
@@ -312,3 +316,8 @@ sub fill_template {
 
 1;
 
+# Local Variables:
+# indent-tabs-mode: nil
+# cperl-indent-level: 4
+# End:
+# vim: syntax=perl sw=4 sts=4 sr et
